'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var entitiesDecode = exports.entitiesDecode = {
  '&AElig': 'Æ',
  '&AElig;': 'Æ',
  '&AMP': '&',
  '&AMP;': '&',
  '&Aacute': 'Á',
  '&Aacute;': 'Á',
  '&Abreve;': 'Ă',
  '&Acirc': 'Â',
  '&Acirc;': 'Â',
  '&Acy;': 'А',
  '&Afr;': '𝔄',
  '&Agrave': 'À',
  '&Agrave;': 'À',
  '&Alpha;': 'Α',
  '&Amacr;': 'Ā',
  '&And;': '⩓',
  '&Aogon;': 'Ą',
  '&Aopf;': '𝔸',
  '&ApplyFunction;': '⁡',
  '&Aring': 'Å',
  '&Aring;': 'Å',
  '&Ascr;': '𝒜',
  '&Assign;': '≔',
  '&Atilde': 'Ã',
  '&Atilde;': 'Ã',
  '&Auml': 'Ä',
  '&Auml;': 'Ä',
  '&Backslash;': '∖',
  '&Barv;': '⫧',
  '&Barwed;': '⌆',
  '&Bcy;': 'Б',
  '&Because;': '∵',
  '&Bernoullis;': 'ℬ',
  '&Beta;': 'Β',
  '&Bfr;': '𝔅',
  '&Bopf;': '𝔹',
  '&Breve;': '˘',
  '&Bscr;': 'ℬ',
  '&Bumpeq;': '≎',
  '&CHcy;': 'Ч',
  '&COPY': '©',
  '&COPY;': '©',
  '&Cacute;': 'Ć',
  '&Cap;': '⋒',
  '&CapitalDifferentialD;': 'ⅅ',
  '&Cayleys;': 'ℭ',
  '&Ccaron;': 'Č',
  '&Ccedil': 'Ç',
  '&Ccedil;': 'Ç',
  '&Ccirc;': 'Ĉ',
  '&Cconint;': '∰',
  '&Cdot;': 'Ċ',
  '&Cedilla;': '¸',
  '&CenterDot;': '·',
  '&Cfr;': 'ℭ',
  '&Chi;': 'Χ',
  '&CircleDot;': '⊙',
  '&CircleMinus;': '⊖',
  '&CirclePlus;': '⊕',
  '&CircleTimes;': '⊗',
  '&ClockwiseContourIntegral;': '∲',
  '&CloseCurlyDoubleQuote;': '”',
  '&CloseCurlyQuote;': '’',
  '&Colon;': '∷',
  '&Colone;': '⩴',
  '&Congruent;': '≡',
  '&Conint;': '∯',
  '&ContourIntegral;': '∮',
  '&Copf;': 'ℂ',
  '&Coproduct;': '∐',
  '&CounterClockwiseContourIntegral;': '∳',
  '&Cross;': '⨯',
  '&Cscr;': '𝒞',
  '&Cup;': '⋓',
  '&CupCap;': '≍',
  '&DD;': 'ⅅ',
  '&DDotrahd;': '⤑',
  '&DJcy;': 'Ђ',
  '&DScy;': 'Ѕ',
  '&DZcy;': 'Џ',
  '&Dagger;': '‡',
  '&Darr;': '↡',
  '&Dashv;': '⫤',
  '&Dcaron;': 'Ď',
  '&Dcy;': 'Д',
  '&Del;': '∇',
  '&Delta;': 'Δ',
  '&Dfr;': '𝔇',
  '&DiacriticalAcute;': '´',
  '&DiacriticalDot;': '˙',
  '&DiacriticalDoubleAcute;': '˝',
  '&DiacriticalGrave;': '`',
  '&DiacriticalTilde;': '˜',
  '&Diamond;': '⋄',
  '&DifferentialD;': 'ⅆ',
  '&Dopf;': '𝔻',
  '&Dot;': '¨',
  '&DotDot;': '⃜',
  '&DotEqual;': '≐',
  '&DoubleContourIntegral;': '∯',
  '&DoubleDot;': '¨',
  '&DoubleDownArrow;': '⇓',
  '&DoubleLeftArrow;': '⇐',
  '&DoubleLeftRightArrow;': '⇔',
  '&DoubleLeftTee;': '⫤',
  '&DoubleLongLeftArrow;': '⟸',
  '&DoubleLongLeftRightArrow;': '⟺',
  '&DoubleLongRightArrow;': '⟹',
  '&DoubleRightArrow;': '⇒',
  '&DoubleRightTee;': '⊨',
  '&DoubleUpArrow;': '⇑',
  '&DoubleUpDownArrow;': '⇕',
  '&DoubleVerticalBar;': '∥',
  '&DownArrow;': '↓',
  '&DownArrowBar;': '⤓',
  '&DownArrowUpArrow;': '⇵',
  '&DownBreve;': '̑',
  '&DownLeftRightVector;': '⥐',
  '&DownLeftTeeVector;': '⥞',
  '&DownLeftVector;': '↽',
  '&DownLeftVectorBar;': '⥖',
  '&DownRightTeeVector;': '⥟',
  '&DownRightVector;': '⇁',
  '&DownRightVectorBar;': '⥗',
  '&DownTee;': '⊤',
  '&DownTeeArrow;': '↧',
  '&Downarrow;': '⇓',
  '&Dscr;': '𝒟',
  '&Dstrok;': 'Đ',
  '&ENG;': 'Ŋ',
  '&ETH': 'Ð',
  '&ETH;': 'Ð',
  '&Eacute': 'É',
  '&Eacute;': 'É',
  '&Ecaron;': 'Ě',
  '&Ecirc': 'Ê',
  '&Ecirc;': 'Ê',
  '&Ecy;': 'Э',
  '&Edot;': 'Ė',
  '&Efr;': '𝔈',
  '&Egrave': 'È',
  '&Egrave;': 'È',
  '&Element;': '∈',
  '&Emacr;': 'Ē',
  '&EmptySmallSquare;': '◻',
  '&EmptyVerySmallSquare;': '▫',
  '&Eogon;': 'Ę',
  '&Eopf;': '𝔼',
  '&Epsilon;': 'Ε',
  '&Equal;': '⩵',
  '&EqualTilde;': '≂',
  '&Equilibrium;': '⇌',
  '&Escr;': 'ℰ',
  '&Esim;': '⩳',
  '&Eta;': 'Η',
  '&Euml': 'Ë',
  '&Euml;': 'Ë',
  '&Exists;': '∃',
  '&ExponentialE;': 'ⅇ',
  '&Fcy;': 'Ф',
  '&Ffr;': '𝔉',
  '&FilledSmallSquare;': '◼',
  '&FilledVerySmallSquare;': '▪',
  '&Fopf;': '𝔽',
  '&ForAll;': '∀',
  '&Fouriertrf;': 'ℱ',
  '&Fscr;': 'ℱ',
  '&GJcy;': 'Ѓ',
  '&GT': '>',
  '&GT;': '>',
  '&Gamma;': 'Γ',
  '&Gammad;': 'Ϝ',
  '&Gbreve;': 'Ğ',
  '&Gcedil;': 'Ģ',
  '&Gcirc;': 'Ĝ',
  '&Gcy;': 'Г',
  '&Gdot;': 'Ġ',
  '&Gfr;': '𝔊',
  '&Gg;': '⋙',
  '&Gopf;': '𝔾',
  '&GreaterEqual;': '≥',
  '&GreaterEqualLess;': '⋛',
  '&GreaterFullEqual;': '≧',
  '&GreaterGreater;': '⪢',
  '&GreaterLess;': '≷',
  '&GreaterSlantEqual;': '⩾',
  '&GreaterTilde;': '≳',
  '&Gscr;': '𝒢',
  '&Gt;': '≫',
  '&HARDcy;': 'Ъ',
  '&Hacek;': 'ˇ',
  '&Hat;': '^',
  '&Hcirc;': 'Ĥ',
  '&Hfr;': 'ℌ',
  '&HilbertSpace;': 'ℋ',
  '&Hopf;': 'ℍ',
  '&HorizontalLine;': '─',
  '&Hscr;': 'ℋ',
  '&Hstrok;': 'Ħ',
  '&HumpDownHump;': '≎',
  '&HumpEqual;': '≏',
  '&IEcy;': 'Е',
  '&IJlig;': 'Ĳ',
  '&IOcy;': 'Ё',
  '&Iacute': 'Í',
  '&Iacute;': 'Í',
  '&Icirc': 'Î',
  '&Icirc;': 'Î',
  '&Icy;': 'И',
  '&Idot;': 'İ',
  '&Ifr;': 'ℑ',
  '&Igrave': 'Ì',
  '&Igrave;': 'Ì',
  '&Im;': 'ℑ',
  '&Imacr;': 'Ī',
  '&ImaginaryI;': 'ⅈ',
  '&Implies;': '⇒',
  '&Int;': '∬',
  '&Integral;': '∫',
  '&Intersection;': '⋂',
  '&InvisibleComma;': '⁣',
  '&InvisibleTimes;': '⁢',
  '&Iogon;': 'Į',
  '&Iopf;': '𝕀',
  '&Iota;': 'Ι',
  '&Iscr;': 'ℐ',
  '&Itilde;': 'Ĩ',
  '&Iukcy;': 'І',
  '&Iuml': 'Ï',
  '&Iuml;': 'Ï',
  '&Jcirc;': 'Ĵ',
  '&Jcy;': 'Й',
  '&Jfr;': '𝔍',
  '&Jopf;': '𝕁',
  '&Jscr;': '𝒥',
  '&Jsercy;': 'Ј',
  '&Jukcy;': 'Є',
  '&KHcy;': 'Х',
  '&KJcy;': 'Ќ',
  '&Kappa;': 'Κ',
  '&Kcedil;': 'Ķ',
  '&Kcy;': 'К',
  '&Kfr;': '𝔎',
  '&Kopf;': '𝕂',
  '&Kscr;': '𝒦',
  '&LJcy;': 'Љ',
  '&LT': '<',
  '&LT;': '<',
  '&Lacute;': 'Ĺ',
  '&Lambda;': 'Λ',
  '&Lang;': '⟪',
  '&Laplacetrf;': 'ℒ',
  '&Larr;': '↞',
  '&Lcaron;': 'Ľ',
  '&Lcedil;': 'Ļ',
  '&Lcy;': 'Л',
  '&LeftAngleBracket;': '⟨',
  '&LeftArrow;': '←',
  '&LeftArrowBar;': '⇤',
  '&LeftArrowRightArrow;': '⇆',
  '&LeftCeiling;': '⌈',
  '&LeftDoubleBracket;': '⟦',
  '&LeftDownTeeVector;': '⥡',
  '&LeftDownVector;': '⇃',
  '&LeftDownVectorBar;': '⥙',
  '&LeftFloor;': '⌊',
  '&LeftRightArrow;': '↔',
  '&LeftRightVector;': '⥎',
  '&LeftTee;': '⊣',
  '&LeftTeeArrow;': '↤',
  '&LeftTeeVector;': '⥚',
  '&LeftTriangle;': '⊲',
  '&LeftTriangleBar;': '⧏',
  '&LeftTriangleEqual;': '⊴',
  '&LeftUpDownVector;': '⥑',
  '&LeftUpTeeVector;': '⥠',
  '&LeftUpVector;': '↿',
  '&LeftUpVectorBar;': '⥘',
  '&LeftVector;': '↼',
  '&LeftVectorBar;': '⥒',
  '&Leftarrow;': '⇐',
  '&Leftrightarrow;': '⇔',
  '&LessEqualGreater;': '⋚',
  '&LessFullEqual;': '≦',
  '&LessGreater;': '≶',
  '&LessLess;': '⪡',
  '&LessSlantEqual;': '⩽',
  '&LessTilde;': '≲',
  '&Lfr;': '𝔏',
  '&Ll;': '⋘',
  '&Lleftarrow;': '⇚',
  '&Lmidot;': 'Ŀ',
  '&LongLeftArrow;': '⟵',
  '&LongLeftRightArrow;': '⟷',
  '&LongRightArrow;': '⟶',
  '&Longleftarrow;': '⟸',
  '&Longleftrightarrow;': '⟺',
  '&Longrightarrow;': '⟹',
  '&Lopf;': '𝕃',
  '&LowerLeftArrow;': '↙',
  '&LowerRightArrow;': '↘',
  '&Lscr;': 'ℒ',
  '&Lsh;': '↰',
  '&Lstrok;': 'Ł',
  '&Lt;': '≪',
  '&Map;': '⤅',
  '&Mcy;': 'М',
  '&MediumSpace;': ' ',
  '&Mellintrf;': 'ℳ',
  '&Mfr;': '𝔐',
  '&MinusPlus;': '∓',
  '&Mopf;': '𝕄',
  '&Mscr;': 'ℳ',
  '&Mu;': 'Μ',
  '&NJcy;': 'Њ',
  '&Nacute;': 'Ń',
  '&Ncaron;': 'Ň',
  '&Ncedil;': 'Ņ',
  '&Ncy;': 'Н',
  '&NegativeMediumSpace;': '​',
  '&NegativeThickSpace;': '​',
  '&NegativeThinSpace;': '​',
  '&NegativeVeryThinSpace;': '​',
  '&NestedGreaterGreater;': '≫',
  '&NestedLessLess;': '≪',
  '&NewLine;': '\n',
  '&Nfr;': '𝔑',
  '&NoBreak;': '⁠',
  '&NonBreakingSpace;': ' ',
  '&Nopf;': 'ℕ',
  '&Not;': '⫬',
  '&NotCongruent;': '≢',
  '&NotCupCap;': '≭',
  '&NotDoubleVerticalBar;': '∦',
  '&NotElement;': '∉',
  '&NotEqual;': '≠',
  '&NotEqualTilde;': '≂̸',
  '&NotExists;': '∄',
  '&NotGreater;': '≯',
  '&NotGreaterEqual;': '≱',
  '&NotGreaterFullEqual;': '≧̸',
  '&NotGreaterGreater;': '≫̸',
  '&NotGreaterLess;': '≹',
  '&NotGreaterSlantEqual;': '⩾̸',
  '&NotGreaterTilde;': '≵',
  '&NotHumpDownHump;': '≎̸',
  '&NotHumpEqual;': '≏̸',
  '&NotLeftTriangle;': '⋪',
  '&NotLeftTriangleBar;': '⧏̸',
  '&NotLeftTriangleEqual;': '⋬',
  '&NotLess;': '≮',
  '&NotLessEqual;': '≰',
  '&NotLessGreater;': '≸',
  '&NotLessLess;': '≪̸',
  '&NotLessSlantEqual;': '⩽̸',
  '&NotLessTilde;': '≴',
  '&NotNestedGreaterGreater;': '⪢̸',
  '&NotNestedLessLess;': '⪡̸',
  '&NotPrecedes;': '⊀',
  '&NotPrecedesEqual;': '⪯̸',
  '&NotPrecedesSlantEqual;': '⋠',
  '&NotReverseElement;': '∌',
  '&NotRightTriangle;': '⋫',
  '&NotRightTriangleBar;': '⧐̸',
  '&NotRightTriangleEqual;': '⋭',
  '&NotSquareSubset;': '⊏̸',
  '&NotSquareSubsetEqual;': '⋢',
  '&NotSquareSuperset;': '⊐̸',
  '&NotSquareSupersetEqual;': '⋣',
  '&NotSubset;': '⊂⃒',
  '&NotSubsetEqual;': '⊈',
  '&NotSucceeds;': '⊁',
  '&NotSucceedsEqual;': '⪰̸',
  '&NotSucceedsSlantEqual;': '⋡',
  '&NotSucceedsTilde;': '≿̸',
  '&NotSuperset;': '⊃⃒',
  '&NotSupersetEqual;': '⊉',
  '&NotTilde;': '≁',
  '&NotTildeEqual;': '≄',
  '&NotTildeFullEqual;': '≇',
  '&NotTildeTilde;': '≉',
  '&NotVerticalBar;': '∤',
  '&Nscr;': '𝒩',
  '&Ntilde': 'Ñ',
  '&Ntilde;': 'Ñ',
  '&Nu;': 'Ν',
  '&OElig;': 'Œ',
  '&Oacute': 'Ó',
  '&Oacute;': 'Ó',
  '&Ocirc': 'Ô',
  '&Ocirc;': 'Ô',
  '&Ocy;': 'О',
  '&Odblac;': 'Ő',
  '&Ofr;': '𝔒',
  '&Ograve': 'Ò',
  '&Ograve;': 'Ò',
  '&Omacr;': 'Ō',
  '&Omega;': 'Ω',
  '&Omicron;': 'Ο',
  '&Oopf;': '𝕆',
  '&OpenCurlyDoubleQuote;': '“',
  '&OpenCurlyQuote;': '‘',
  '&Or;': '⩔',
  '&Oscr;': '𝒪',
  '&Oslash': 'Ø',
  '&Oslash;': 'Ø',
  '&Otilde': 'Õ',
  '&Otilde;': 'Õ',
  '&Otimes;': '⨷',
  '&Ouml': 'Ö',
  '&Ouml;': 'Ö',
  '&OverBar;': '‾',
  '&OverBrace;': '⏞',
  '&OverBracket;': '⎴',
  '&OverParenthesis;': '⏜',
  '&PartialD;': '∂',
  '&Pcy;': 'П',
  '&Pfr;': '𝔓',
  '&Phi;': 'Φ',
  '&Pi;': 'Π',
  '&PlusMinus;': '±',
  '&Poincareplane;': 'ℌ',
  '&Popf;': 'ℙ',
  '&Pr;': '⪻',
  '&Precedes;': '≺',
  '&PrecedesEqual;': '⪯',
  '&PrecedesSlantEqual;': '≼',
  '&PrecedesTilde;': '≾',
  '&Prime;': '″',
  '&Product;': '∏',
  '&Proportion;': '∷',
  '&Proportional;': '∝',
  '&Pscr;': '𝒫',
  '&Psi;': 'Ψ',
  '&QUOT': '"',
  '&QUOT;': '"',
  '&Qfr;': '𝔔',
  '&Qopf;': 'ℚ',
  '&Qscr;': '𝒬',
  '&RBarr;': '⤐',
  '&REG': '®',
  '&REG;': '®',
  '&Racute;': 'Ŕ',
  '&Rang;': '⟫',
  '&Rarr;': '↠',
  '&Rarrtl;': '⤖',
  '&Rcaron;': 'Ř',
  '&Rcedil;': 'Ŗ',
  '&Rcy;': 'Р',
  '&Re;': 'ℜ',
  '&ReverseElement;': '∋',
  '&ReverseEquilibrium;': '⇋',
  '&ReverseUpEquilibrium;': '⥯',
  '&Rfr;': 'ℜ',
  '&Rho;': 'Ρ',
  '&RightAngleBracket;': '⟩',
  '&RightArrow;': '→',
  '&RightArrowBar;': '⇥',
  '&RightArrowLeftArrow;': '⇄',
  '&RightCeiling;': '⌉',
  '&RightDoubleBracket;': '⟧',
  '&RightDownTeeVector;': '⥝',
  '&RightDownVector;': '⇂',
  '&RightDownVectorBar;': '⥕',
  '&RightFloor;': '⌋',
  '&RightTee;': '⊢',
  '&RightTeeArrow;': '↦',
  '&RightTeeVector;': '⥛',
  '&RightTriangle;': '⊳',
  '&RightTriangleBar;': '⧐',
  '&RightTriangleEqual;': '⊵',
  '&RightUpDownVector;': '⥏',
  '&RightUpTeeVector;': '⥜',
  '&RightUpVector;': '↾',
  '&RightUpVectorBar;': '⥔',
  '&RightVector;': '⇀',
  '&RightVectorBar;': '⥓',
  '&Rightarrow;': '⇒',
  '&Ropf;': 'ℝ',
  '&RoundImplies;': '⥰',
  '&Rrightarrow;': '⇛',
  '&Rscr;': 'ℛ',
  '&Rsh;': '↱',
  '&RuleDelayed;': '⧴',
  '&SHCHcy;': 'Щ',
  '&SHcy;': 'Ш',
  '&SOFTcy;': 'Ь',
  '&Sacute;': 'Ś',
  '&Sc;': '⪼',
  '&Scaron;': 'Š',
  '&Scedil;': 'Ş',
  '&Scirc;': 'Ŝ',
  '&Scy;': 'С',
  '&Sfr;': '𝔖',
  '&ShortDownArrow;': '↓',
  '&ShortLeftArrow;': '←',
  '&ShortRightArrow;': '→',
  '&ShortUpArrow;': '↑',
  '&Sigma;': 'Σ',
  '&SmallCircle;': '∘',
  '&Sopf;': '𝕊',
  '&Sqrt;': '√',
  '&Square;': '□',
  '&SquareIntersection;': '⊓',
  '&SquareSubset;': '⊏',
  '&SquareSubsetEqual;': '⊑',
  '&SquareSuperset;': '⊐',
  '&SquareSupersetEqual;': '⊒',
  '&SquareUnion;': '⊔',
  '&Sscr;': '𝒮',
  '&Star;': '⋆',
  '&Sub;': '⋐',
  '&Subset;': '⋐',
  '&SubsetEqual;': '⊆',
  '&Succeeds;': '≻',
  '&SucceedsEqual;': '⪰',
  '&SucceedsSlantEqual;': '≽',
  '&SucceedsTilde;': '≿',
  '&SuchThat;': '∋',
  '&Sum;': '∑',
  '&Sup;': '⋑',
  '&Superset;': '⊃',
  '&SupersetEqual;': '⊇',
  '&Supset;': '⋑',
  '&THORN': 'Þ',
  '&THORN;': 'Þ',
  '&TRADE;': '™',
  '&TSHcy;': 'Ћ',
  '&TScy;': 'Ц',
  '&Tab;': '\t',
  '&Tau;': 'Τ',
  '&Tcaron;': 'Ť',
  '&Tcedil;': 'Ţ',
  '&Tcy;': 'Т',
  '&Tfr;': '𝔗',
  '&Therefore;': '∴',
  '&Theta;': 'Θ',
  '&ThickSpace;': '  ',
  '&ThinSpace;': ' ',
  '&Tilde;': '∼',
  '&TildeEqual;': '≃',
  '&TildeFullEqual;': '≅',
  '&TildeTilde;': '≈',
  '&Topf;': '𝕋',
  '&TripleDot;': '⃛',
  '&Tscr;': '𝒯',
  '&Tstrok;': 'Ŧ',
  '&Uacute': 'Ú',
  '&Uacute;': 'Ú',
  '&Uarr;': '↟',
  '&Uarrocir;': '⥉',
  '&Ubrcy;': 'Ў',
  '&Ubreve;': 'Ŭ',
  '&Ucirc': 'Û',
  '&Ucirc;': 'Û',
  '&Ucy;': 'У',
  '&Udblac;': 'Ű',
  '&Ufr;': '𝔘',
  '&Ugrave': 'Ù',
  '&Ugrave;': 'Ù',
  '&Umacr;': 'Ū',
  '&UnderBar;': '_',
  '&UnderBrace;': '⏟',
  '&UnderBracket;': '⎵',
  '&UnderParenthesis;': '⏝',
  '&Union;': '⋃',
  '&UnionPlus;': '⊎',
  '&Uogon;': 'Ų',
  '&Uopf;': '𝕌',
  '&UpArrow;': '↑',
  '&UpArrowBar;': '⤒',
  '&UpArrowDownArrow;': '⇅',
  '&UpDownArrow;': '↕',
  '&UpEquilibrium;': '⥮',
  '&UpTee;': '⊥',
  '&UpTeeArrow;': '↥',
  '&Uparrow;': '⇑',
  '&Updownarrow;': '⇕',
  '&UpperLeftArrow;': '↖',
  '&UpperRightArrow;': '↗',
  '&Upsi;': 'ϒ',
  '&Upsilon;': 'Υ',
  '&Uring;': 'Ů',
  '&Uscr;': '𝒰',
  '&Utilde;': 'Ũ',
  '&Uuml': 'Ü',
  '&Uuml;': 'Ü',
  '&VDash;': '⊫',
  '&Vbar;': '⫫',
  '&Vcy;': 'В',
  '&Vdash;': '⊩',
  '&Vdashl;': '⫦',
  '&Vee;': '⋁',
  '&Verbar;': '‖',
  '&Vert;': '‖',
  '&VerticalBar;': '∣',
  '&VerticalLine;': '|',
  '&VerticalSeparator;': '❘',
  '&VerticalTilde;': '≀',
  '&VeryThinSpace;': ' ',
  '&Vfr;': '𝔙',
  '&Vopf;': '𝕍',
  '&Vscr;': '𝒱',
  '&Vvdash;': '⊪',
  '&Wcirc;': 'Ŵ',
  '&Wedge;': '⋀',
  '&Wfr;': '𝔚',
  '&Wopf;': '𝕎',
  '&Wscr;': '𝒲',
  '&Xfr;': '𝔛',
  '&Xi;': 'Ξ',
  '&Xopf;': '𝕏',
  '&Xscr;': '𝒳',
  '&YAcy;': 'Я',
  '&YIcy;': 'Ї',
  '&YUcy;': 'Ю',
  '&Yacute': 'Ý',
  '&Yacute;': 'Ý',
  '&Ycirc;': 'Ŷ',
  '&Ycy;': 'Ы',
  '&Yfr;': '𝔜',
  '&Yopf;': '𝕐',
  '&Yscr;': '𝒴',
  '&Yuml;': 'Ÿ',
  '&ZHcy;': 'Ж',
  '&Zacute;': 'Ź',
  '&Zcaron;': 'Ž',
  '&Zcy;': 'З',
  '&Zdot;': 'Ż',
  '&ZeroWidthSpace;': '​',
  '&Zeta;': 'Ζ',
  '&Zfr;': 'ℨ',
  '&Zopf;': 'ℤ',
  '&Zscr;': '𝒵',
  '&aacute;': 'á',
  '&abreve;': 'ă',
  '&ac;': '∾',
  '&acE;': '∾̳',
  '&acd;': '∿',
  '&acirc': 'â',
  '&acirc;': 'â',
  '&acute': '´',
  '&acute;': '´',
  '&acy;': 'а',
  '&aelig': 'æ',
  '&aelig;': 'æ',
  '&af;': '⁡',
  '&afr;': '𝔞',
  '&agrave': 'à',
  '&agrave;': 'à',
  '&alefsym;': 'ℵ',
  '&aleph;': 'ℵ',
  '&alpha;': 'α',
  '&amacr;': 'ā',
  '&amalg;': '⨿',
  '&amp': '&',
  '&amp;': '&',
  '&and;': '∧',
  '&andand;': '⩕',
  '&andd;': '⩜',
  '&andslope;': '⩘',
  '&andv;': '⩚',
  '&ang;': '∠',
  '&ange;': '⦤',
  '&angle;': '∠',
  '&angmsd;': '∡',
  '&angmsdaa;': '⦨',
  '&angmsdab;': '⦩',
  '&angmsdac;': '⦪',
  '&angmsdad;': '⦫',
  '&angmsdae;': '⦬',
  '&angmsdaf;': '⦭',
  '&angmsdag;': '⦮',
  '&angmsdah;': '⦯',
  '&angrt;': '∟',
  '&angrtvb;': '⊾',
  '&angrtvbd;': '⦝',
  '&angsph;': '∢',
  '&angst;': 'Å',
  '&angzarr;': '⍼',
  '&aogon;': 'ą',
  '&aopf;': '𝕒',
  '&ap;': '≈',
  '&apE;': '⩰',
  '&apacir;': '⩯',
  '&ape;': '≊',
  '&apid;': '≋',
  '&apos;': '\'',
  '&approx;': '≈',
  '&approxeq;': '≊',
  '&aring': 'å',
  '&aring;': 'å',
  '&ascr;': '𝒶',
  '&ast;': '*',
  '&asymp;': '≈',
  '&asympeq;': '≍',
  '&atilde': 'ã',
  '&atilde;': 'ã',
  '&auml': 'ä',
  '&auml;': 'ä',
  '&awconint;': '∳',
  '&awint;': '⨑',
  '&bNot;': '⫭',
  '&backcong;': '≌',
  '&backepsilon;': '϶',
  '&backprime;': '‵',
  '&backsim;': '∽',
  '&backsimeq;': '⋍',
  '&barvee;': '⊽',
  '&barwed;': '⌅',
  '&barwedge;': '⌅',
  '&bbrk;': '⎵',
  '&bbrktbrk;': '⎶',
  '&bcong;': '≌',
  '&bcy;': 'б',
  '&bdquo;': '„',
  '&becaus;': '∵',
  '&because;': '∵',
  '&bemptyv;': '⦰',
  '&bepsi;': '϶',
  '&bernou;': 'ℬ',
  '&beta;': 'β',
  '&beth;': 'ℶ',
  '&between;': '≬',
  '&bfr;': '𝔟',
  '&bigcap;': '⋂',
  '&bigcirc;': '◯',
  '&bigcup;': '⋃',
  '&bigodot;': '⨀',
  '&bigoplus;': '⨁',
  '&bigotimes;': '⨂',
  '&bigsqcup;': '⨆',
  '&bigstar;': '★',
  '&bigtriangledown;': '▽',
  '&bigtriangleup;': '△',
  '&biguplus;': '⨄',
  '&bigvee;': '⋁',
  '&bigwedge;': '⋀',
  '&bkarow;': '⤍',
  '&blacklozenge;': '⧫',
  '&blacksquare;': '▪',
  '&blacktriangle;': '▴',
  '&blacktriangledown;': '▾',
  '&blacktriangleleft;': '◂',
  '&blacktriangleright;': '▸',
  '&blank;': '␣',
  '&blk12;': '▒',
  '&blk14;': '░',
  '&blk34;': '▓',
  '&block;': '█',
  '&bne;': '=⃥',
  '&bnequiv;': '≡⃥',
  '&bnot;': '⌐',
  '&bopf;': '𝕓',
  '&bot;': '⊥',
  '&bottom;': '⊥',
  '&bowtie;': '⋈',
  '&boxDL;': '╗',
  '&boxDR;': '╔',
  '&boxDl;': '╖',
  '&boxDr;': '╓',
  '&boxH;': '═',
  '&boxHD;': '╦',
  '&boxHU;': '╩',
  '&boxHd;': '╤',
  '&boxHu;': '╧',
  '&boxUL;': '╝',
  '&boxUR;': '╚',
  '&boxUl;': '╜',
  '&boxUr;': '╙',
  '&boxV;': '║',
  '&boxVH;': '╬',
  '&boxVL;': '╣',
  '&boxVR;': '╠',
  '&boxVh;': '╫',
  '&boxVl;': '╢',
  '&boxVr;': '╟',
  '&boxbox;': '⧉',
  '&boxdL;': '╕',
  '&boxdR;': '╒',
  '&boxdl;': '┐',
  '&boxdr;': '┌',
  '&boxh;': '─',
  '&boxhD;': '╥',
  '&boxhU;': '╨',
  '&boxhd;': '┬',
  '&boxhu;': '┴',
  '&boxminus;': '⊟',
  '&boxplus;': '⊞',
  '&boxtimes;': '⊠',
  '&boxuL;': '╛',
  '&boxuR;': '╘',
  '&boxul;': '┘',
  '&boxur;': '└',
  '&boxv;': '│',
  '&boxvH;': '╪',
  '&boxvL;': '╡',
  '&boxvR;': '╞',
  '&boxvh;': '┼',
  '&boxvl;': '┤',
  '&boxvr;': '├',
  '&bprime;': '‵',
  '&breve;': '˘',
  '&brvbar': '¦',
  '&brvbar;': '¦',
  '&bscr;': '𝒷',
  '&bsemi;': '⁏',
  '&bsim;': '∽',
  '&bsime;': '⋍',
  '&bsol;': '\\',
  '&bsolb;': '⧅',
  '&bsolhsub;': '⟈',
  '&bull;': '•',
  '&bullet;': '•',
  '&bump;': '≎',
  '&bumpE;': '⪮',
  '&bumpe;': '≏',
  '&bumpeq;': '≏',
  '&cacute;': 'ć',
  '&cap;': '∩',
  '&capand;': '⩄',
  '&capbrcup;': '⩉',
  '&capcap;': '⩋',
  '&capcup;': '⩇',
  '&capdot;': '⩀',
  '&caps;': '∩︀',
  '&caret;': '⁁',
  '&caron;': 'ˇ',
  '&ccaps;': '⩍',
  '&ccaron;': 'č',
  '&ccedil': 'ç',
  '&ccedil;': 'ç',
  '&ccirc;': 'ĉ',
  '&ccups;': '⩌',
  '&ccupssm;': '⩐',
  '&cdot;': 'ċ',
  '&cedil': '¸',
  '&cedil;': '¸',
  '&cemptyv;': '⦲',
  '&cent': '¢',
  '&cent;': '¢',
  '&centerdot;': '·',
  '&cfr;': '𝔠',
  '&chcy;': 'ч',
  '&check;': '✓',
  '&checkmark;': '✓',
  '&chi;': 'χ',
  '&cir;': '○',
  '&cirE;': '⧃',
  '&circ;': 'ˆ',
  '&circeq;': '≗',
  '&circlearrowleft;': '↺',
  '&circlearrowright;': '↻',
  '&circledR;': '®',
  '&circledS;': 'Ⓢ',
  '&circledast;': '⊛',
  '&circledcirc;': '⊚',
  '&circleddash;': '⊝',
  '&cire;': '≗',
  '&cirfnint;': '⨐',
  '&cirmid;': '⫯',
  '&cirscir;': '⧂',
  '&clubs;': '♣',
  '&clubsuit;': '♣',
  '&colon;': ':',
  '&colone;': '≔',
  '&coloneq;': '≔',
  '&comma;': ',',
  '&commat;': '@',
  '&comp;': '∁',
  '&compfn;': '∘',
  '&complement;': '∁',
  '&complexes;': 'ℂ',
  '&cong;': '≅',
  '&congdot;': '⩭',
  '&conint;': '∮',
  '&copf;': '𝕔',
  '&coprod;': '∐',
  '&copy': '©',
  '&copy;': '©',
  '&copysr;': '℗',
  '&crarr;': '↵',
  '&cross;': '✗',
  '&cscr;': '𝒸',
  '&csub;': '⫏',
  '&csube;': '⫑',
  '&csup;': '⫐',
  '&csupe;': '⫒',
  '&ctdot;': '⋯',
  '&cudarrl;': '⤸',
  '&cudarrr;': '⤵',
  '&cuepr;': '⋞',
  '&cuesc;': '⋟',
  '&cularr;': '↶',
  '&cularrp;': '⤽',
  '&cup;': '∪',
  '&cupbrcap;': '⩈',
  '&cupcap;': '⩆',
  '&cupcup;': '⩊',
  '&cupdot;': '⊍',
  '&cupor;': '⩅',
  '&cups;': '∪︀',
  '&curarr;': '↷',
  '&curarrm;': '⤼',
  '&curlyeqprec;': '⋞',
  '&curlyeqsucc;': '⋟',
  '&curlyvee;': '⋎',
  '&curlywedge;': '⋏',
  '&curren': '¤',
  '&curren;': '¤',
  '&curvearrowleft;': '↶',
  '&curvearrowright;': '↷',
  '&cuvee;': '⋎',
  '&cuwed;': '⋏',
  '&cwconint;': '∲',
  '&cwint;': '∱',
  '&cylcty;': '⌭',
  '&dArr;': '⇓',
  '&dHar;': '⥥',
  '&dagger;': '†',
  '&daleth;': 'ℸ',
  '&darr;': '↓',
  '&dash;': '‐',
  '&dashv;': '⊣',
  '&dbkarow;': '⤏',
  '&dblac;': '˝',
  '&dcaron;': 'ď',
  '&dcy;': 'д',
  '&dd;': 'ⅆ',
  '&ddagger;': '‡',
  '&ddarr;': '⇊',
  '&ddotseq;': '⩷',
  '&deg': '°',
  '&deg;': '°',
  '&delta;': 'δ',
  '&demptyv;': '⦱',
  '&dfisht;': '⥿',
  '&dfr;': '𝔡',
  '&dharl;': '⇃',
  '&dharr;': '⇂',
  '&diam;': '⋄',
  '&diamond;': '⋄',
  '&diamondsuit;': '♦',
  '&diams;': '♦',
  '&die;': '¨',
  '&digamma;': 'ϝ',
  '&disin;': '⋲',
  '&div;': '÷',
  '&divide': '÷',
  '&divide;': '÷',
  '&divideontimes;': '⋇',
  '&divonx;': '⋇',
  '&djcy;': 'ђ',
  '&dlcorn;': '⌞',
  '&dlcrop;': '⌍',
  '&dollar;': '$',
  '&dopf;': '𝕕',
  '&dot;': '˙',
  '&doteq;': '≐',
  '&doteqdot;': '≑',
  '&dotminus;': '∸',
  '&dotplus;': '∔',
  '&dotsquare;': '⊡',
  '&doublebarwedge;': '⌆',
  '&downarrow;': '↓',
  '&downdownarrows;': '⇊',
  '&downharpoonleft;': '⇃',
  '&downharpoonright;': '⇂',
  '&drbkarow;': '⤐',
  '&drcorn;': '⌟',
  '&drcrop;': '⌌',
  '&dscr;': '𝒹',
  '&dscy;': 'ѕ',
  '&dsol;': '⧶',
  '&dstrok;': 'đ',
  '&dtdot;': '⋱',
  '&dtri;': '▿',
  '&dtrif;': '▾',
  '&duarr;': '⇵',
  '&duhar;': '⥯',
  '&dwangle;': '⦦',
  '&dzcy;': 'џ',
  '&dzigrarr;': '⟿',
  '&eDDot;': '⩷',
  '&eDot;': '≑',
  '&eacute;': 'é',
  '&easter;': '⩮',
  '&ecaron;': 'ě',
  '&ecir;': '≖',
  '&ecirc': 'ê',
  '&ecirc;': 'ê',
  '&ecolon;': '≕',
  '&ecy;': 'э',
  '&edot;': 'ė',
  '&ee;': 'ⅇ',
  '&efDot;': '≒',
  '&efr;': '𝔢',
  '&eg;': '⪚',
  '&egrave': 'è',
  '&egrave;': 'è',
  '&egs;': '⪖',
  '&egsdot;': '⪘',
  '&el;': '⪙',
  '&elinters;': '⏧',
  '&ell;': 'ℓ',
  '&els;': '⪕',
  '&elsdot;': '⪗',
  '&emacr;': 'ē',
  '&empty;': '∅',
  '&emptyset;': '∅',
  '&emptyv;': '∅',
  '&emsp13;': ' ',
  '&emsp14;': ' ',
  '&emsp;': ' ',
  '&eng;': 'ŋ',
  '&ensp;': ' ',
  '&eogon;': 'ę',
  '&eopf;': '𝕖',
  '&epar;': '⋕',
  '&eparsl;': '⧣',
  '&eplus;': '⩱',
  '&epsi;': 'ε',
  '&epsilon;': 'ε',
  '&epsiv;': 'ϵ',
  '&eqcirc;': '≖',
  '&eqcolon;': '≕',
  '&eqsim;': '≂',
  '&eqslantgtr;': '⪖',
  '&eqslantless;': '⪕',
  '&equals;': '=',
  '&equest;': '≟',
  '&equiv;': '≡',
  '&equivDD;': '⩸',
  '&eqvparsl;': '⧥',
  '&erDot;': '≓',
  '&erarr;': '⥱',
  '&escr;': 'ℯ',
  '&esdot;': '≐',
  '&esim;': '≂',
  '&eta;': 'η',
  '&eth': 'ð',
  '&eth;': 'ð',
  '&euml': 'ë',
  '&euml;': 'ë',
  '&euro;': '€',
  '&excl;': '!',
  '&exist;': '∃',
  '&expectation;': 'ℰ',
  '&exponentiale;': 'ⅇ',
  '&fallingdotseq;': '≒',
  '&fcy;': 'ф',
  '&female;': '♀',
  '&ffilig;': 'ﬃ',
  '&fflig;': 'ﬀ',
  '&ffllig;': 'ﬄ',
  '&ffr;': '𝔣',
  '&filig;': 'ﬁ',
  '&fjlig;': 'fj',
  '&flat;': '♭',
  '&fllig;': 'ﬂ',
  '&fltns;': '▱',
  '&fnof;': 'ƒ',
  '&fopf;': '𝕗',
  '&forall;': '∀',
  '&fork;': '⋔',
  '&forkv;': '⫙',
  '&fpartint;': '⨍',
  '&frac12': '½',
  '&frac12;': '½',
  '&frac13;': '⅓',
  '&frac14': '¼',
  '&frac14;': '¼',
  '&frac15;': '⅕',
  '&frac16;': '⅙',
  '&frac18;': '⅛',
  '&frac23;': '⅔',
  '&frac25;': '⅖',
  '&frac34': '¾',
  '&frac34;': '¾',
  '&frac35;': '⅗',
  '&frac38;': '⅜',
  '&frac45;': '⅘',
  '&frac56;': '⅚',
  '&frac58;': '⅝',
  '&frac78;': '⅞',
  '&frasl;': '⁄',
  '&frown;': '⌢',
  '&fscr;': '𝒻',
  '&gE;': '≧',
  '&gEl;': '⪌',
  '&gacute;': 'ǵ',
  '&gamma;': 'γ',
  '&gammad;': 'ϝ',
  '&gap;': '⪆',
  '&gbreve;': 'ğ',
  '&gcirc;': 'ĝ',
  '&gcy;': 'г',
  '&gdot;': 'ġ',
  '&ge;': '≥',
  '&gel;': '⋛',
  '&geq;': '≥',
  '&geqq;': '≧',
  '&geqslant;': '⩾',
  '&ges;': '⩾',
  '&gescc;': '⪩',
  '&gesdot;': '⪀',
  '&gesdoto;': '⪂',
  '&gesdotol;': '⪄',
  '&gesl;': '⋛︀',
  '&gesles;': '⪔',
  '&gfr;': '𝔤',
  '&gg;': '≫',
  '&ggg;': '⋙',
  '&gimel;': 'ℷ',
  '&gjcy;': 'ѓ',
  '&gl;': '≷',
  '&glE;': '⪒',
  '&gla;': '⪥',
  '&glj;': '⪤',
  '&gnE;': '≩',
  '&gnap;': '⪊',
  '&gnapprox;': '⪊',
  '&gne;': '⪈',
  '&gneq;': '⪈',
  '&gneqq;': '≩',
  '&gnsim;': '⋧',
  '&gopf;': '𝕘',
  '&grave;': '`',
  '&gscr;': 'ℊ',
  '&gsim;': '≳',
  '&gsime;': '⪎',
  '&gsiml;': '⪐',
  '&gt': '>',
  '&gt;': '>',
  '&gtcc;': '⪧',
  '&gtcir;': '⩺',
  '&gtdot;': '⋗',
  '&gtlPar;': '⦕',
  '&gtquest;': '⩼',
  '&gtrapprox;': '⪆',
  '&gtrarr;': '⥸',
  '&gtrdot;': '⋗',
  '&gtreqless;': '⋛',
  '&gtreqqless;': '⪌',
  '&gtrless;': '≷',
  '&gtrsim;': '≳',
  '&gvertneqq;': '≩︀',
  '&gvnE;': '≩︀',
  '&hArr;': '⇔',
  '&hairsp;': ' ',
  '&half;': '½',
  '&hamilt;': 'ℋ',
  '&hardcy;': 'ъ',
  '&harr;': '↔',
  '&harrcir;': '⥈',
  '&harrw;': '↭',
  '&hbar;': 'ℏ',
  '&hcirc;': 'ĥ',
  '&hearts;': '♥',
  '&heartsuit;': '♥',
  '&hellip;': '…',
  '&hercon;': '⊹',
  '&hfr;': '𝔥',
  '&hksearow;': '⤥',
  '&hkswarow;': '⤦',
  '&hoarr;': '⇿',
  '&homtht;': '∻',
  '&hookleftarrow;': '↩',
  '&hookrightarrow;': '↪',
  '&hopf;': '𝕙',
  '&horbar;': '―',
  '&hscr;': '𝒽',
  '&hslash;': 'ℏ',
  '&hstrok;': 'ħ',
  '&hybull;': '⁃',
  '&hyphen;': '‐',
  '&iacute': 'í',
  '&iacute;': 'í',
  '&ic;': '⁣',
  '&icirc': 'î',
  '&icirc;': 'î',
  '&icy;': 'и',
  '&iecy;': 'е',
  '&iexcl': '¡',
  '&iexcl;': '¡',
  '&iff;': '⇔',
  '&ifr;': '𝔦',
  '&igrave': 'ì',
  '&igrave;': 'ì',
  '&ii;': 'ⅈ',
  '&iiiint;': '⨌',
  '&iiint;': '∭',
  '&iinfin;': '⧜',
  '&iiota;': '℩',
  '&ijlig;': 'ĳ',
  '&imacr;': 'ī',
  '&image;': 'ℑ',
  '&imagline;': 'ℐ',
  '&imagpart;': 'ℑ',
  '&imath;': 'ı',
  '&imof;': '⊷',
  '&imped;': 'Ƶ',
  '&in;': '∈',
  '&incare;': '℅',
  '&infin;': '∞',
  '&infintie;': '⧝',
  '&inodot;': 'ı',
  '&int;': '∫',
  '&intcal;': '⊺',
  '&integers;': 'ℤ',
  '&intercal;': '⊺',
  '&intlarhk;': '⨗',
  '&intprod;': '⨼',
  '&iocy;': 'ё',
  '&iogon;': 'į',
  '&iopf;': '𝕚',
  '&iota;': 'ι',
  '&iprod;': '⨼',
  '&iquest': '¿',
  '&iquest;': '¿',
  '&iscr;': '𝒾',
  '&isin;': '∈',
  '&isinE;': '⋹',
  '&isindot;': '⋵',
  '&isins;': '⋴',
  '&isinsv;': '⋳',
  '&isinv;': '∈',
  '&it;': '⁢',
  '&itilde;': 'ĩ',
  '&iukcy;': 'і',
  '&iuml': 'ï',
  '&iuml;': 'ï',
  '&jcirc;': 'ĵ',
  '&jcy;': 'й',
  '&jfr;': '𝔧',
  '&jmath;': 'ȷ',
  '&jopf;': '𝕛',
  '&jscr;': '𝒿',
  '&jsercy;': 'ј',
  '&jukcy;': 'є',
  '&kappa;': 'κ',
  '&kappav;': 'ϰ',
  '&kcedil;': 'ķ',
  '&kcy;': 'к',
  '&kfr;': '𝔨',
  '&kgreen;': 'ĸ',
  '&khcy;': 'х',
  '&kjcy;': 'ќ',
  '&kopf;': '𝕜',
  '&kscr;': '𝓀',
  '&lAarr;': '⇚',
  '&lArr;': '⇐',
  '&lAtail;': '⤛',
  '&lBarr;': '⤎',
  '&lE;': '≦',
  '&lEg;': '⪋',
  '&lHar;': '⥢',
  '&lacute;': 'ĺ',
  '&laemptyv;': '⦴',
  '&lagran;': 'ℒ',
  '&lambda;': 'λ',
  '&lang;': '⟨',
  '&langd;': '⦑',
  '&langle;': '⟨',
  '&lap;': '⪅',
  '&laquo': '«',
  '&laquo;': '«',
  '&larr;': '←',
  '&larrb;': '⇤',
  '&larrbfs;': '⤟',
  '&larrfs;': '⤝',
  '&larrhk;': '↩',
  '&larrlp;': '↫',
  '&larrpl;': '⤹',
  '&larrsim;': '⥳',
  '&larrtl;': '↢',
  '&lat;': '⪫',
  '&latail;': '⤙',
  '&late;': '⪭',
  '&lates;': '⪭︀',
  '&lbarr;': '⤌',
  '&lbbrk;': '❲',
  '&lbrace;': '{',
  '&lbrack;': '[',
  '&lbrke;': '⦋',
  '&lbrksld;': '⦏',
  '&lbrkslu;': '⦍',
  '&lcaron;': 'ľ',
  '&lcedil;': 'ļ',
  '&lceil;': '⌈',
  '&lcub;': '{',
  '&lcy;': 'л',
  '&ldca;': '⤶',
  '&ldquo;': '“',
  '&ldquor;': '„',
  '&ldrdhar;': '⥧',
  '&ldrushar;': '⥋',
  '&ldsh;': '↲',
  '&le;': '≤',
  '&leftarrow;': '←',
  '&leftarrowtail;': '↢',
  '&leftharpoondown;': '↽',
  '&leftharpoonup;': '↼',
  '&leftleftarrows;': '⇇',
  '&leftrightarrow;': '↔',
  '&leftrightarrows;': '⇆',
  '&leftrightharpoons;': '⇋',
  '&leftrightsquigarrow;': '↭',
  '&leftthreetimes;': '⋋',
  '&leg;': '⋚',
  '&leq;': '≤',
  '&leqq;': '≦',
  '&leqslant;': '⩽',
  '&les;': '⩽',
  '&lescc;': '⪨',
  '&lesdot;': '⩿',
  '&lesdoto;': '⪁',
  '&lesdotor;': '⪃',
  '&lesg;': '⋚︀',
  '&lesges;': '⪓',
  '&lessapprox;': '⪅',
  '&lessdot;': '⋖',
  '&lesseqgtr;': '⋚',
  '&lesseqqgtr;': '⪋',
  '&lessgtr;': '≶',
  '&lesssim;': '≲',
  '&lfisht;': '⥼',
  '&lfloor;': '⌊',
  '&lfr;': '𝔩',
  '&lg;': '≶',
  '&lgE;': '⪑',
  '&lhard;': '↽',
  '&lharu;': '↼',
  '&lharul;': '⥪',
  '&lhblk;': '▄',
  '&ljcy;': 'љ',
  '&ll;': '≪',
  '&llarr;': '⇇',
  '&llcorner;': '⌞',
  '&llhard;': '⥫',
  '&lltri;': '◺',
  '&lmidot;': 'ŀ',
  '&lmoust;': '⎰',
  '&lmoustache;': '⎰',
  '&lnE;': '≨',
  '&lnap;': '⪉',
  '&lnapprox;': '⪉',
  '&lne;': '⪇',
  '&lneq;': '⪇',
  '&lneqq;': '≨',
  '&lnsim;': '⋦',
  '&loang;': '⟬',
  '&loarr;': '⇽',
  '&lobrk;': '⟦',
  '&longleftarrow;': '⟵',
  '&longleftrightarrow;': '⟷',
  '&longmapsto;': '⟼',
  '&longrightarrow;': '⟶',
  '&looparrowleft;': '↫',
  '&looparrowright;': '↬',
  '&lopar;': '⦅',
  '&lopf;': '𝕝',
  '&loplus;': '⨭',
  '&lotimes;': '⨴',
  '&lowast;': '∗',
  '&lowbar;': '_',
  '&loz;': '◊',
  '&lozenge;': '◊',
  '&lozf;': '⧫',
  '&lpar;': '(',
  '&lparlt;': '⦓',
  '&lrarr;': '⇆',
  '&lrcorner;': '⌟',
  '&lrhar;': '⇋',
  '&lrhard;': '⥭',
  '&lrm;': '‎',
  '&lrtri;': '⊿',
  '&lsaquo;': '‹',
  '&lscr;': '𝓁',
  '&lsh;': '↰',
  '&lsim;': '≲',
  '&lsime;': '⪍',
  '&lsimg;': '⪏',
  '&lsqb;': '[',
  '&lsquo;': '‘',
  '&lsquor;': '‚',
  '&lstrok;': 'ł',
  '&lt': '<',
  '&lt;': '<',
  '&ltcc;': '⪦',
  '&ltcir;': '⩹',
  '&ltdot;': '⋖',
  '&lthree;': '⋋',
  '&ltimes;': '⋉',
  '&ltlarr;': '⥶',
  '&ltquest;': '⩻',
  '&ltrPar;': '⦖',
  '&ltri;': '◃',
  '&ltrie;': '⊴',
  '&ltrif;': '◂',
  '&lurdshar;': '⥊',
  '&luruhar;': '⥦',
  '&lvertneqq;': '≨︀',
  '&lvnE;': '≨︀',
  '&mDDot;': '∺',
  '&macr': '¯',
  '&macr;': '¯',
  '&male;': '♂',
  '&malt;': '✠',
  '&maltese;': '✠',
  '&map;': '↦',
  '&mapsto;': '↦',
  '&mapstodown;': '↧',
  '&mapstoleft;': '↤',
  '&mapstoup;': '↥',
  '&marker;': '▮',
  '&mcomma;': '⨩',
  '&mcy;': 'м',
  '&mdash;': '—',
  '&measuredangle;': '∡',
  '&mfr;': '𝔪',
  '&mho;': '℧',
  '&micro': 'µ',
  '&micro;': 'µ',
  '&mid;': '∣',
  '&midast;': '*',
  '&midcir;': '⫰',
  '&middot': '·',
  '&middot;': '·',
  '&minus;': '−',
  '&minusb;': '⊟',
  '&minusd;': '∸',
  '&minusdu;': '⨪',
  '&mlcp;': '⫛',
  '&mldr;': '…',
  '&mnplus;': '∓',
  '&models;': '⊧',
  '&mopf;': '𝕞',
  '&mp;': '∓',
  '&mscr;': '𝓂',
  '&mstpos;': '∾',
  '&mu;': 'μ',
  '&multimap;': '⊸',
  '&mumap;': '⊸',
  '&nGg;': '⋙̸',
  '&nGt;': '≫⃒',
  '&nGtv;': '≫̸',
  '&nLeftarrow;': '⇍',
  '&nLeftrightarrow;': '⇎',
  '&nLl;': '⋘̸',
  '&nLt;': '≪⃒',
  '&nLtv;': '≪̸',
  '&nRightarrow;': '⇏',
  '&nVDash;': '⊯',
  '&nVdash;': '⊮',
  '&nabla;': '∇',
  '&nacute;': 'ń',
  '&nang;': '∠⃒',
  '&nap;': '≉',
  '&napE;': '⩰̸',
  '&napid;': '≋̸',
  '&napos;': 'ŉ',
  '&napprox;': '≉',
  '&natur;': '♮',
  '&natural;': '♮',
  '&naturals;': 'ℕ',
  '&nbsp': ' ',
  '&nbsp;': ' ',
  '&nbump;': '≎̸',
  '&nbumpe;': '≏̸',
  '&ncap;': '⩃',
  '&ncaron;': 'ň',
  '&ncedil;': 'ņ',
  '&ncong;': '≇',
  '&ncongdot;': '⩭̸',
  '&ncup;': '⩂',
  '&ncy;': 'н',
  '&ndash;': '–',
  '&ne;': '≠',
  '&neArr;': '⇗',
  '&nearhk;': '⤤',
  '&nearr;': '↗',
  '&nearrow;': '↗',
  '&nedot;': '≐̸',
  '&nequiv;': '≢',
  '&nesear;': '⤨',
  '&nesim;': '≂̸',
  '&nexist;': '∄',
  '&nexists;': '∄',
  '&nfr;': '𝔫',
  '&ngE;': '≧̸',
  '&nge;': '≱',
  '&ngeq;': '≱',
  '&ngeqq;': '≧̸',
  '&ngeqslant;': '⩾̸',
  '&nges;': '⩾̸',
  '&ngsim;': '≵',
  '&ngt;': '≯',
  '&ngtr;': '≯',
  '&nhArr;': '⇎',
  '&nharr;': '↮',
  '&nhpar;': '⫲',
  '&ni;': '∋',
  '&nis;': '⋼',
  '&nisd;': '⋺',
  '&niv;': '∋',
  '&njcy;': 'њ',
  '&nlArr;': '⇍',
  '&nlE;': '≦̸',
  '&nlarr;': '↚',
  '&nldr;': '‥',
  '&nle;': '≰',
  '&nleftarrow;': '↚',
  '&nleftrightarrow;': '↮',
  '&nleq;': '≰',
  '&nleqq;': '≦̸',
  '&nleqslant;': '⩽̸',
  '&nles;': '⩽̸',
  '&nless;': '≮',
  '&nlsim;': '≴',
  '&nlt;': '≮',
  '&nltri;': '⋪',
  '&nltrie;': '⋬',
  '&nmid;': '∤',
  '&nopf;': '𝕟',
  '&not': '¬',
  '&not;': '¬',
  '&notin;': '∉',
  '&notinE;': '⋹̸',
  '&notindot;': '⋵̸',
  '&notinva;': '∉',
  '&notinvb;': '⋷',
  '&notinvc;': '⋶',
  '&notni;': '∌',
  '&notniva;': '∌',
  '&notnivb;': '⋾',
  '&notnivc;': '⋽',
  '&npar;': '∦',
  '&nparallel;': '∦',
  '&nparsl;': '⫽⃥',
  '&npart;': '∂̸',
  '&npolint;': '⨔',
  '&npr;': '⊀',
  '&nprcue;': '⋠',
  '&npre;': '⪯̸',
  '&nprec;': '⊀',
  '&npreceq;': '⪯̸',
  '&nrArr;': '⇏',
  '&nrarr;': '↛',
  '&nrarrc;': '⤳̸',
  '&nrarrw;': '↝̸',
  '&nrightarrow;': '↛',
  '&nrtri;': '⋫',
  '&nrtrie;': '⋭',
  '&nsc;': '⊁',
  '&nsccue;': '⋡',
  '&nsce;': '⪰̸',
  '&nscr;': '𝓃',
  '&nshortmid;': '∤',
  '&nshortparallel;': '∦',
  '&nsim;': '≁',
  '&nsime;': '≄',
  '&nsimeq;': '≄',
  '&nsmid;': '∤',
  '&nspar;': '∦',
  '&nsqsube;': '⋢',
  '&nsqsupe;': '⋣',
  '&nsub;': '⊄',
  '&nsubE;': '⫅̸',
  '&nsube;': '⊈',
  '&nsubset;': '⊂⃒',
  '&nsubseteq;': '⊈',
  '&nsubseteqq;': '⫅̸',
  '&nsucc;': '⊁',
  '&nsucceq;': '⪰̸',
  '&nsup;': '⊅',
  '&nsupE;': '⫆̸',
  '&nsupe;': '⊉',
  '&nsupset;': '⊃⃒',
  '&nsupseteq;': '⊉',
  '&nsupseteqq;': '⫆̸',
  '&ntgl;': '≹',
  '&ntilde': 'ñ',
  '&ntilde;': 'ñ',
  '&ntlg;': '≸',
  '&ntriangleleft;': '⋪',
  '&ntrianglelefteq;': '⋬',
  '&ntriangleright;': '⋫',
  '&ntrianglerighteq;': '⋭',
  '&nu;': 'ν',
  '&num;': '#',
  '&numero;': '№',
  '&numsp;': ' ',
  '&nvDash;': '⊭',
  '&nvHarr;': '⤄',
  '&nvap;': '≍⃒',
  '&nvdash;': '⊬',
  '&nvge;': '≥⃒',
  '&nvgt;': '>⃒',
  '&nvinfin;': '⧞',
  '&nvlArr;': '⤂',
  '&nvle;': '≤⃒',
  '&nvlt;': '<⃒',
  '&nvltrie;': '⊴⃒',
  '&nvrArr;': '⤃',
  '&nvrtrie;': '⊵⃒',
  '&nvsim;': '∼⃒',
  '&nwArr;': '⇖',
  '&nwarhk;': '⤣',
  '&nwarr;': '↖',
  '&nwarrow;': '↖',
  '&nwnear;': '⤧',
  '&oS;': 'Ⓢ',
  '&oacute': 'ó',
  '&oacute;': 'ó',
  '&oast;': '⊛',
  '&ocir;': '⊚',
  '&ocirc': 'ô',
  '&ocirc;': 'ô',
  '&ocy;': 'о',
  '&odash;': '⊝',
  '&odblac;': 'ő',
  '&odiv;': '⨸',
  '&odot;': '⊙',
  '&odsold;': '⦼',
  '&oelig;': 'œ',
  '&ofcir;': '⦿',
  '&ofr;': '𝔬',
  '&ogon;': '˛',
  '&ograve': 'ò',
  '&ograve;': 'ò',
  '&ogt;': '⧁',
  '&ohbar;': '⦵',
  '&ohm;': 'Ω',
  '&oint;': '∮',
  '&olarr;': '↺',
  '&olcir;': '⦾',
  '&olcross;': '⦻',
  '&oline;': '‾',
  '&olt;': '⧀',
  '&omacr;': 'ō',
  '&omega;': 'ω',
  '&omicron;': 'ο',
  '&omid;': '⦶',
  '&ominus;': '⊖',
  '&oopf;': '𝕠',
  '&opar;': '⦷',
  '&operp;': '⦹',
  '&oplus;': '⊕',
  '&or;': '∨',
  '&orarr;': '↻',
  '&ord;': '⩝',
  '&order;': 'ℴ',
  '&orderof;': 'ℴ',
  '&ordf': 'ª',
  '&ordf;': 'ª',
  '&ordm': 'º',
  '&ordm;': 'º',
  '&origof;': '⊶',
  '&oror;': '⩖',
  '&orslope;': '⩗',
  '&orv;': '⩛',
  '&oscr;': 'ℴ',
  '&oslash': 'ø',
  '&oslash;': 'ø',
  '&osol;': '⊘',
  '&otilde': 'õ',
  '&otilde;': 'õ',
  '&otimes;': '⊗',
  '&otimesas;': '⨶',
  '&ouml': 'ö',
  '&ouml;': 'ö',
  '&ovbar;': '⌽',
  '&par;': '∥',
  '&para': '¶',
  '&para;': '¶',
  '&parallel;': '∥',
  '&parsim;': '⫳',
  '&parsl;': '⫽',
  '&part;': '∂',
  '&pcy;': 'п',
  '&percnt;': '%',
  '&period;': '.',
  '&permil;': '‰',
  '&perp;': '⊥',
  '&pertenk;': '‱',
  '&pfr;': '𝔭',
  '&phi;': 'φ',
  '&phiv;': 'ϕ',
  '&phmmat;': 'ℳ',
  '&phone;': '☎',
  '&pi;': 'π',
  '&pitchfork;': '⋔',
  '&piv;': 'ϖ',
  '&planck;': 'ℏ',
  '&planckh;': 'ℎ',
  '&plankv;': 'ℏ',
  '&plus;': '+',
  '&plusacir;': '⨣',
  '&plusb;': '⊞',
  '&pluscir;': '⨢',
  '&plusdo;': '∔',
  '&plusdu;': '⨥',
  '&pluse;': '⩲',
  '&plusmn': '±',
  '&plusmn;': '±',
  '&plussim;': '⨦',
  '&plustwo;': '⨧',
  '&pm;': '±',
  '&pointint;': '⨕',
  '&popf;': '𝕡',
  '&pound': '£',
  '&pound;': '£',
  '&pr;': '≺',
  '&prE;': '⪳',
  '&prap;': '⪷',
  '&prcue;': '≼',
  '&pre;': '⪯',
  '&prec;': '≺',
  '&precapprox;': '⪷',
  '&preccurlyeq;': '≼',
  '&preceq;': '⪯',
  '&precnapprox;': '⪹',
  '&precneqq;': '⪵',
  '&precnsim;': '⋨',
  '&precsim;': '≾',
  '&prime;': '′',
  '&primes;': 'ℙ',
  '&prnE;': '⪵',
  '&prnap;': '⪹',
  '&prnsim;': '⋨',
  '&prod;': '∏',
  '&profalar;': '⌮',
  '&profline;': '⌒',
  '&profsurf;': '⌓',
  '&prop;': '∝',
  '&propto;': '∝',
  '&prsim;': '≾',
  '&prurel;': '⊰',
  '&pscr;': '𝓅',
  '&psi;': 'ψ',
  '&puncsp;': ' ',
  '&qfr;': '𝔮',
  '&qint;': '⨌',
  '&qopf;': '𝕢',
  '&qprime;': '⁗',
  '&qscr;': '𝓆',
  '&quaternions;': 'ℍ',
  '&quatint;': '⨖',
  '&quest;': '?',
  '&questeq;': '≟',
  '&quot': '"',
  '&quot;': '"',
  '&rAarr;': '⇛',
  '&rArr;': '⇒',
  '&rAtail;': '⤜',
  '&rBarr;': '⤏',
  '&rHar;': '⥤',
  '&race;': '∽̱',
  '&racute;': 'ŕ',
  '&radic;': '√',
  '&raemptyv;': '⦳',
  '&rang;': '⟩',
  '&rangd;': '⦒',
  '&range;': '⦥',
  '&rangle;': '⟩',
  '&raquo': '»',
  '&raquo;': '»',
  '&rarr;': '→',
  '&rarrap;': '⥵',
  '&rarrb;': '⇥',
  '&rarrbfs;': '⤠',
  '&rarrc;': '⤳',
  '&rarrfs;': '⤞',
  '&rarrhk;': '↪',
  '&rarrlp;': '↬',
  '&rarrpl;': '⥅',
  '&rarrsim;': '⥴',
  '&rarrtl;': '↣',
  '&rarrw;': '↝',
  '&ratail;': '⤚',
  '&ratio;': '∶',
  '&rationals;': 'ℚ',
  '&rbarr;': '⤍',
  '&rbbrk;': '❳',
  '&rbrace;': '}',
  '&rbrack;': ']',
  '&rbrke;': '⦌',
  '&rbrksld;': '⦎',
  '&rbrkslu;': '⦐',
  '&rcaron;': 'ř',
  '&rcedil;': 'ŗ',
  '&rceil;': '⌉',
  '&rcub;': '}',
  '&rcy;': 'р',
  '&rdca;': '⤷',
  '&rdldhar;': '⥩',
  '&rdquo;': '”',
  '&rdquor;': '”',
  '&rdsh;': '↳',
  '&real;': 'ℜ',
  '&realine;': 'ℛ',
  '&realpart;': 'ℜ',
  '&reals;': 'ℝ',
  '&rect;': '▭',
  '&reg': '®',
  '&reg;': '®',
  '&rfisht;': '⥽',
  '&rfloor;': '⌋',
  '&rfr;': '𝔯',
  '&rhard;': '⇁',
  '&rharu;': '⇀',
  '&rharul;': '⥬',
  '&rho;': 'ρ',
  '&rhov;': 'ϱ',
  '&rightarrow;': '→',
  '&rightarrowtail;': '↣',
  '&rightharpoondown;': '⇁',
  '&rightharpoonup;': '⇀',
  '&rightleftarrows;': '⇄',
  '&rightleftharpoons;': '⇌',
  '&rightrightarrows;': '⇉',
  '&rightsquigarrow;': '↝',
  '&rightthreetimes;': '⋌',
  '&ring;': '˚',
  '&risingdotseq;': '≓',
  '&rlarr;': '⇄',
  '&rlhar;': '⇌',
  '&rlm;': '‏',
  '&rmoust;': '⎱',
  '&rmoustache;': '⎱',
  '&rnmid;': '⫮',
  '&roang;': '⟭',
  '&roarr;': '⇾',
  '&robrk;': '⟧',
  '&ropar;': '⦆',
  '&ropf;': '𝕣',
  '&roplus;': '⨮',
  '&rotimes;': '⨵',
  '&rpar;': ')',
  '&rpargt;': '⦔',
  '&rppolint;': '⨒',
  '&rrarr;': '⇉',
  '&rsaquo;': '›',
  '&rscr;': '𝓇',
  '&rsh;': '↱',
  '&rsqb;': ']',
  '&rsquo;': '’',
  '&rsquor;': '’',
  '&rthree;': '⋌',
  '&rtimes;': '⋊',
  '&rtri;': '▹',
  '&rtrie;': '⊵',
  '&rtrif;': '▸',
  '&rtriltri;': '⧎',
  '&ruluhar;': '⥨',
  '&rx;': '℞',
  '&sacute;': 'ś',
  '&sbquo;': '‚',
  '&sc;': '≻',
  '&scE;': '⪴',
  '&scap;': '⪸',
  '&scaron;': 'š',
  '&sccue;': '≽',
  '&sce;': '⪰',
  '&scedil;': 'ş',
  '&scirc;': 'ŝ',
  '&scnE;': '⪶',
  '&scnap;': '⪺',
  '&scnsim;': '⋩',
  '&scpolint;': '⨓',
  '&scsim;': '≿',
  '&scy;': 'с',
  '&sdot;': '⋅',
  '&sdotb;': '⊡',
  '&sdote;': '⩦',
  '&seArr;': '⇘',
  '&searhk;': '⤥',
  '&searr;': '↘',
  '&searrow;': '↘',
  '&sect': '§',
  '&sect;': '§',
  '&semi;': ';',
  '&seswar;': '⤩',
  '&setminus;': '∖',
  '&setmn;': '∖',
  '&sext;': '✶',
  '&sfr;': '𝔰',
  '&sfrown;': '⌢',
  '&sharp;': '♯',
  '&shchcy;': 'щ',
  '&shcy;': 'ш',
  '&shortmid;': '∣',
  '&shortparallel;': '∥',
  '&shy': '­',
  '&shy;': '­',
  '&sigma;': 'σ',
  '&sigmaf;': 'ς',
  '&sigmav;': 'ς',
  '&sim;': '∼',
  '&simdot;': '⩪',
  '&sime;': '≃',
  '&simeq;': '≃',
  '&simg;': '⪞',
  '&simgE;': '⪠',
  '&siml;': '⪝',
  '&simlE;': '⪟',
  '&simne;': '≆',
  '&simplus;': '⨤',
  '&simrarr;': '⥲',
  '&slarr;': '←',
  '&smallsetminus;': '∖',
  '&smashp;': '⨳',
  '&smeparsl;': '⧤',
  '&smid;': '∣',
  '&smile;': '⌣',
  '&smt;': '⪪',
  '&smte;': '⪬',
  '&smtes;': '⪬︀',
  '&softcy;': 'ь',
  '&sol;': '/',
  '&solb;': '⧄',
  '&solbar;': '⌿',
  '&sopf;': '𝕤',
  '&spades;': '♠',
  '&spadesuit;': '♠',
  '&spar;': '∥',
  '&sqcap;': '⊓',
  '&sqcaps;': '⊓︀',
  '&sqcup;': '⊔',
  '&sqcups;': '⊔︀',
  '&sqsub;': '⊏',
  '&sqsube;': '⊑',
  '&sqsubset;': '⊏',
  '&sqsubseteq;': '⊑',
  '&sqsup;': '⊐',
  '&sqsupe;': '⊒',
  '&sqsupset;': '⊐',
  '&sqsupseteq;': '⊒',
  '&squ;': '□',
  '&square;': '□',
  '&squarf;': '▪',
  '&squf;': '▪',
  '&srarr;': '→',
  '&sscr;': '𝓈',
  '&ssetmn;': '∖',
  '&ssmile;': '⌣',
  '&sstarf;': '⋆',
  '&star;': '☆',
  '&starf;': '★',
  '&straightepsilon;': 'ϵ',
  '&straightphi;': 'ϕ',
  '&strns;': '¯',
  '&sub;': '⊂',
  '&subE;': '⫅',
  '&subdot;': '⪽',
  '&sube;': '⊆',
  '&subedot;': '⫃',
  '&submult;': '⫁',
  '&subnE;': '⫋',
  '&subne;': '⊊',
  '&subplus;': '⪿',
  '&subrarr;': '⥹',
  '&subset;': '⊂',
  '&subseteq;': '⊆',
  '&subseteqq;': '⫅',
  '&subsetneq;': '⊊',
  '&subsetneqq;': '⫋',
  '&subsim;': '⫇',
  '&subsub;': '⫕',
  '&subsup;': '⫓',
  '&succ;': '≻',
  '&succapprox;': '⪸',
  '&succcurlyeq;': '≽',
  '&succeq;': '⪰',
  '&succnapprox;': '⪺',
  '&succneqq;': '⪶',
  '&succnsim;': '⋩',
  '&succsim;': '≿',
  '&sum;': '∑',
  '&sung;': '♪',
  '&sup1': '¹',
  '&sup1;': '¹',
  '&sup2': '²',
  '&sup2;': '²',
  '&sup3': '³',
  '&sup3;': '³',
  '&sup;': '⊃',
  '&supE;': '⫆',
  '&supdot;': '⪾',
  '&supdsub;': '⫘',
  '&supe;': '⊇',
  '&supedot;': '⫄',
  '&suphsol;': '⟉',
  '&suphsub;': '⫗',
  '&suplarr;': '⥻',
  '&supmult;': '⫂',
  '&supnE;': '⫌',
  '&supne;': '⊋',
  '&supplus;': '⫀',
  '&supset;': '⊃',
  '&supseteq;': '⊇',
  '&supseteqq;': '⫆',
  '&supsetneq;': '⊋',
  '&supsetneqq;': '⫌',
  '&supsim;': '⫈',
  '&supsub;': '⫔',
  '&supsup;': '⫖',
  '&swArr;': '⇙',
  '&swarhk;': '⤦',
  '&swarr;': '↙',
  '&swarrow;': '↙',
  '&swnwar;': '⤪',
  '&szlig': 'ß',
  '&szlig;': 'ß',
  '&target;': '⌖',
  '&tau;': 'τ',
  '&tbrk;': '⎴',
  '&tcaron;': 'ť',
  '&tcedil;': 'ţ',
  '&tcy;': 'т',
  '&tdot;': '⃛',
  '&telrec;': '⌕',
  '&tfr;': '𝔱',
  '&there4;': '∴',
  '&therefore;': '∴',
  '&theta;': 'θ',
  '&thetasym;': 'ϑ',
  '&thetav;': 'ϑ',
  '&thickapprox;': '≈',
  '&thicksim;': '∼',
  '&thinsp;': ' ',
  '&thkap;': '≈',
  '&thksim;': '∼',
  '&thorn': 'þ',
  '&thorn;': 'þ',
  '&tilde;': '˜',
  '&times': '×',
  '&times;': '×',
  '&timesb;': '⊠',
  '&timesbar;': '⨱',
  '&timesd;': '⨰',
  '&tint;': '∭',
  '&toea;': '⤨',
  '&top;': '⊤',
  '&topbot;': '⌶',
  '&topcir;': '⫱',
  '&topf;': '𝕥',
  '&topfork;': '⫚',
  '&tosa;': '⤩',
  '&tprime;': '‴',
  '&trade;': '™',
  '&triangle;': '▵',
  '&triangledown;': '▿',
  '&triangleleft;': '◃',
  '&trianglelefteq;': '⊴',
  '&triangleq;': '≜',
  '&triangleright;': '▹',
  '&trianglerighteq;': '⊵',
  '&tridot;': '◬',
  '&trie;': '≜',
  '&triminus;': '⨺',
  '&triplus;': '⨹',
  '&trisb;': '⧍',
  '&tritime;': '⨻',
  '&trpezium;': '⏢',
  '&tscr;': '𝓉',
  '&tscy;': 'ц',
  '&tshcy;': 'ћ',
  '&tstrok;': 'ŧ',
  '&twixt;': '≬',
  '&twoheadleftarrow;': '↞',
  '&twoheadrightarrow;': '↠',
  '&uArr;': '⇑',
  '&uHar;': '⥣',
  '&uacute': 'ú',
  '&uacute;': 'ú',
  '&uarr;': '↑',
  '&ubrcy;': 'ў',
  '&ubreve;': 'ŭ',
  '&ucirc': 'û',
  '&ucirc;': 'û',
  '&ucy;': 'у',
  '&udarr;': '⇅',
  '&udblac;': 'ű',
  '&udhar;': '⥮',
  '&ufisht;': '⥾',
  '&ufr;': '𝔲',
  '&ugrave': 'ù',
  '&ugrave;': 'ù',
  '&uharl;': '↿',
  '&uharr;': '↾',
  '&uhblk;': '▀',
  '&ulcorn;': '⌜',
  '&ulcorner;': '⌜',
  '&ulcrop;': '⌏',
  '&ultri;': '◸',
  '&umacr;': 'ū',
  '&uml': '¨',
  '&uml;': '¨',
  '&uogon;': 'ų',
  '&uopf;': '𝕦',
  '&uparrow;': '↑',
  '&updownarrow;': '↕',
  '&upharpoonleft;': '↿',
  '&upharpoonright;': '↾',
  '&uplus;': '⊎',
  '&upsi;': 'υ',
  '&upsih;': 'ϒ',
  '&upsilon;': 'υ',
  '&upuparrows;': '⇈',
  '&urcorn;': '⌝',
  '&urcorner;': '⌝',
  '&urcrop;': '⌎',
  '&uring;': 'ů',
  '&urtri;': '◹',
  '&uscr;': '𝓊',
  '&utdot;': '⋰',
  '&utilde;': 'ũ',
  '&utri;': '▵',
  '&utrif;': '▴',
  '&uuarr;': '⇈',
  '&uuml': 'ü',
  '&uuml;': 'ü',
  '&uwangle;': '⦧',
  '&vArr;': '⇕',
  '&vBar;': '⫨',
  '&vBarv;': '⫩',
  '&vDash;': '⊨',
  '&vangrt;': '⦜',
  '&varepsilon;': 'ϵ',
  '&varkappa;': 'ϰ',
  '&varnothing;': '∅',
  '&varphi;': 'ϕ',
  '&varpi;': 'ϖ',
  '&varpropto;': '∝',
  '&varr;': '↕',
  '&varrho;': 'ϱ',
  '&varsigma;': 'ς',
  '&varsubsetneq;': '⊊︀',
  '&varsubsetneqq;': '⫋︀',
  '&varsupsetneq;': '⊋︀',
  '&varsupsetneqq;': '⫌︀',
  '&vartheta;': 'ϑ',
  '&vartriangleleft;': '⊲',
  '&vartriangleright;': '⊳',
  '&vcy;': 'в',
  '&vdash;': '⊢',
  '&vee;': '∨',
  '&veebar;': '⊻',
  '&veeeq;': '≚',
  '&vellip;': '⋮',
  '&verbar;': '|',
  '&vert;': '|',
  '&vfr;': '𝔳',
  '&vltri;': '⊲',
  '&vnsub;': '⊂⃒',
  '&vnsup;': '⊃⃒',
  '&vopf;': '𝕧',
  '&vprop;': '∝',
  '&vrtri;': '⊳',
  '&vscr;': '𝓋',
  '&vsubnE;': '⫋︀',
  '&vsubne;': '⊊︀',
  '&vsupnE;': '⫌︀',
  '&vsupne;': '⊋︀',
  '&vzigzag;': '⦚',
  '&wcirc;': 'ŵ',
  '&wedbar;': '⩟',
  '&wedge;': '∧',
  '&wedgeq;': '≙',
  '&weierp;': '℘',
  '&wfr;': '𝔴',
  '&wopf;': '𝕨',
  '&wp;': '℘',
  '&wr;': '≀',
  '&wreath;': '≀',
  '&wscr;': '𝓌',
  '&xcap;': '⋂',
  '&xcirc;': '◯',
  '&xcup;': '⋃',
  '&xdtri;': '▽',
  '&xfr;': '𝔵',
  '&xhArr;': '⟺',
  '&xharr;': '⟷',
  '&xi;': 'ξ',
  '&xlArr;': '⟸',
  '&xlarr;': '⟵',
  '&xmap;': '⟼',
  '&xnis;': '⋻',
  '&xodot;': '⨀',
  '&xopf;': '𝕩',
  '&xoplus;': '⨁',
  '&xotime;': '⨂',
  '&xrArr;': '⟹',
  '&xrarr;': '⟶',
  '&xscr;': '𝓍',
  '&xsqcup;': '⨆',
  '&xuplus;': '⨄',
  '&xutri;': '△',
  '&xvee;': '⋁',
  '&xwedge;': '⋀',
  '&yacute': 'ý',
  '&yacute;': 'ý',
  '&yacy;': 'я',
  '&ycirc;': 'ŷ',
  '&ycy;': 'ы',
  '&yen': '¥',
  '&yen;': '¥',
  '&yfr;': '𝔶',
  '&yicy;': 'ї',
  '&yopf;': '𝕪',
  '&yscr;': '𝓎',
  '&yucy;': 'ю',
  '&yuml': 'ÿ',
  '&yuml;': 'ÿ',
  '&zacute;': 'ź',
  '&zcaron;': 'ž',
  '&zcy;': 'з',
  '&zdot;': 'ż',
  '&zeetrf;': 'ℨ',
  '&zeta;': 'ζ',
  '&zfr;': '𝔷',
  '&zhcy;': 'ж',
  '&zigrarr;': '⇝',
  '&zopf;': '𝕫',
  '&zscr;': '𝓏',
  '&zwj;': '‍',
  '&zwnj;': '‌'
};

var entitiesEncode = exports.entitiesEncode = {
  'Æ': '&AElig;',
  '&': '&AMP;',
  'Á': '&Aacute;',
  'Ă': '&Abreve;',
  'Â': '&Acirc;',
  'А': '&Acy;',
  '𝔄': '&Afr;',
  'À': '&Agrave;',
  'Α': '&Alpha;',
  'Ā': '&Amacr;',
  '⩓': '&And;',
  'Ą': '&Aogon;',
  '𝔸': '&Aopf;',
  '⁡': '&ApplyFunction;',
  'Å': '&Aring;',
  '𝒜': '&Ascr;',
  '≔': '&Assign;',
  'Ã': '&Atilde;',
  'Ä': '&Auml;',
  '∖': '&Backslash;',
  '⫧': '&Barv;',
  '⌆': '&Barwed;',
  'Б': '&Bcy;',
  '∵': '&Because;',
  'ℬ': '&Bernoullis;',
  'Β': '&Beta;',
  '𝔅': '&Bfr;',
  '𝔹': '&Bopf;',
  '˘': '&Breve;',
  '≎': '&Bumpeq;',
  'Ч': '&CHcy;',
  '©': '&COPY;',
  'Ć': '&Cacute;',
  '⋒': '&Cap;',
  'ⅅ': '&CapitalDifferentialD;',
  'ℭ': '&Cayleys;',
  'Č': '&Ccaron;',
  'Ç': '&Ccedil;',
  'Ĉ': '&Ccirc;',
  '∰': '&Cconint;',
  'Ċ': '&Cdot;',
  '¸': '&Cedilla;',
  '·': '&CenterDot;',
  'Χ': '&Chi;',
  '⊙': '&CircleDot;',
  '⊖': '&CircleMinus;',
  '⊕': '&CirclePlus;',
  '⊗': '&CircleTimes;',
  '∲': '&ClockwiseContourIntegral;',
  '”': '&CloseCurlyDoubleQuote;',
  '’': '&CloseCurlyQuote;',
  '∷': '&Colon;',
  '⩴': '&Colone;',
  '≡': '&Congruent;',
  '∯': '&Conint;',
  '∮': '&ContourIntegral;',
  'ℂ': '&Copf;',
  '∐': '&Coproduct;',
  '∳': '&CounterClockwiseContourIntegral;',
  '⨯': '&Cross;',
  '𝒞': '&Cscr;',
  '⋓': '&Cup;',
  '≍': '&CupCap;',
  '⤑': '&DDotrahd;',
  'Ђ': '&DJcy;',
  'Ѕ': '&DScy;',
  'Џ': '&DZcy;',
  '‡': '&Dagger;',
  '↡': '&Darr;',
  '⫤': '&Dashv;',
  'Ď': '&Dcaron;',
  'Д': '&Dcy;',
  '∇': '&Del;',
  'Δ': '&Delta;',
  '𝔇': '&Dfr;',
  '´': '&DiacriticalAcute;',
  '˙': '&DiacriticalDot;',
  '˝': '&DiacriticalDoubleAcute;',
  '`': '&DiacriticalGrave;',
  '˜': '&DiacriticalTilde;',
  '⋄': '&Diamond;',
  'ⅆ': '&DifferentialD;',
  '𝔻': '&Dopf;',
  '¨': '&Dot;',
  '⃜': '&DotDot;',
  '≐': '&DotEqual;',
  '⇓': '&DoubleDownArrow;',
  '⇐': '&DoubleLeftArrow;',
  '⇔': '&DoubleLeftRightArrow;',
  '⟸': '&DoubleLongLeftArrow;',
  '⟺': '&DoubleLongLeftRightArrow;',
  '⟹': '&DoubleLongRightArrow;',
  '⇒': '&DoubleRightArrow;',
  '⊨': '&DoubleRightTee;',
  '⇑': '&DoubleUpArrow;',
  '⇕': '&DoubleUpDownArrow;',
  '∥': '&DoubleVerticalBar;',
  '↓': '&DownArrow;',
  '⤓': '&DownArrowBar;',
  '⇵': '&DownArrowUpArrow;',
  '̑': '&DownBreve;',
  '⥐': '&DownLeftRightVector;',
  '⥞': '&DownLeftTeeVector;',
  '↽': '&DownLeftVector;',
  '⥖': '&DownLeftVectorBar;',
  '⥟': '&DownRightTeeVector;',
  '⇁': '&DownRightVector;',
  '⥗': '&DownRightVectorBar;',
  '⊤': '&DownTee;',
  '↧': '&DownTeeArrow;',
  '𝒟': '&Dscr;',
  'Đ': '&Dstrok;',
  'Ŋ': '&ENG;',
  'Ð': '&ETH;',
  'É': '&Eacute;',
  'Ě': '&Ecaron;',
  'Ê': '&Ecirc;',
  'Э': '&Ecy;',
  'Ė': '&Edot;',
  '𝔈': '&Efr;',
  'È': '&Egrave;',
  '∈': '&Element;',
  'Ē': '&Emacr;',
  '◻': '&EmptySmallSquare;',
  '▫': '&EmptyVerySmallSquare;',
  'Ę': '&Eogon;',
  '𝔼': '&Eopf;',
  'Ε': '&Epsilon;',
  '⩵': '&Equal;',
  '≂': '&EqualTilde;',
  '⇌': '&Equilibrium;',
  'ℰ': '&Escr;',
  '⩳': '&Esim;',
  'Η': '&Eta;',
  'Ë': '&Euml;',
  '∃': '&Exists;',
  'ⅇ': '&ExponentialE;',
  'Ф': '&Fcy;',
  '𝔉': '&Ffr;',
  '◼': '&FilledSmallSquare;',
  '▪': '&FilledVerySmallSquare;',
  '𝔽': '&Fopf;',
  '∀': '&ForAll;',
  'ℱ': '&Fouriertrf;',
  'Ѓ': '&GJcy;',
  '>': '&GT;',
  'Γ': '&Gamma;',
  'Ϝ': '&Gammad;',
  'Ğ': '&Gbreve;',
  'Ģ': '&Gcedil;',
  'Ĝ': '&Gcirc;',
  'Г': '&Gcy;',
  'Ġ': '&Gdot;',
  '𝔊': '&Gfr;',
  '⋙': '&Gg;',
  '𝔾': '&Gopf;',
  '≥': '&GreaterEqual;',
  '⋛': '&GreaterEqualLess;',
  '≧': '&GreaterFullEqual;',
  '⪢': '&GreaterGreater;',
  '≷': '&GreaterLess;',
  '⩾': '&GreaterSlantEqual;',
  '≳': '&GreaterTilde;',
  '𝒢': '&Gscr;',
  '≫': '&Gt;',
  'Ъ': '&HARDcy;',
  'ˇ': '&Hacek;',
  '^': '&Hat;',
  'Ĥ': '&Hcirc;',
  'ℌ': '&Hfr;',
  'ℋ': '&HilbertSpace;',
  'ℍ': '&Hopf;',
  '─': '&HorizontalLine;',
  'Ħ': '&Hstrok;',
  '≏': '&HumpEqual;',
  'Е': '&IEcy;',
  'Ĳ': '&IJlig;',
  'Ё': '&IOcy;',
  'Í': '&Iacute;',
  'Î': '&Icirc;',
  'И': '&Icy;',
  'İ': '&Idot;',
  'ℑ': '&Ifr;',
  'Ì': '&Igrave;',
  'Ī': '&Imacr;',
  'ⅈ': '&ImaginaryI;',
  '∬': '&Int;',
  '∫': '&Integral;',
  '⋂': '&Intersection;',
  '⁣': '&InvisibleComma;',
  '⁢': '&InvisibleTimes;',
  'Į': '&Iogon;',
  '𝕀': '&Iopf;',
  'Ι': '&Iota;',
  'ℐ': '&Iscr;',
  'Ĩ': '&Itilde;',
  'І': '&Iukcy;',
  'Ï': '&Iuml;',
  'Ĵ': '&Jcirc;',
  'Й': '&Jcy;',
  '𝔍': '&Jfr;',
  '𝕁': '&Jopf;',
  '𝒥': '&Jscr;',
  'Ј': '&Jsercy;',
  'Є': '&Jukcy;',
  'Х': '&KHcy;',
  'Ќ': '&KJcy;',
  'Κ': '&Kappa;',
  'Ķ': '&Kcedil;',
  'К': '&Kcy;',
  '𝔎': '&Kfr;',
  '𝕂': '&Kopf;',
  '𝒦': '&Kscr;',
  'Љ': '&LJcy;',
  '<': '&LT;',
  'Ĺ': '&Lacute;',
  'Λ': '&Lambda;',
  '⟪': '&Lang;',
  'ℒ': '&Laplacetrf;',
  '↞': '&Larr;',
  'Ľ': '&Lcaron;',
  'Ļ': '&Lcedil;',
  'Л': '&Lcy;',
  '⟨': '&LeftAngleBracket;',
  '←': '&LeftArrow;',
  '⇤': '&LeftArrowBar;',
  '⇆': '&LeftArrowRightArrow;',
  '⌈': '&LeftCeiling;',
  '⟦': '&LeftDoubleBracket;',
  '⥡': '&LeftDownTeeVector;',
  '⇃': '&LeftDownVector;',
  '⥙': '&LeftDownVectorBar;',
  '⌊': '&LeftFloor;',
  '↔': '&LeftRightArrow;',
  '⥎': '&LeftRightVector;',
  '⊣': '&LeftTee;',
  '↤': '&LeftTeeArrow;',
  '⥚': '&LeftTeeVector;',
  '⊲': '&LeftTriangle;',
  '⧏': '&LeftTriangleBar;',
  '⊴': '&LeftTriangleEqual;',
  '⥑': '&LeftUpDownVector;',
  '⥠': '&LeftUpTeeVector;',
  '↿': '&LeftUpVector;',
  '⥘': '&LeftUpVectorBar;',
  '↼': '&LeftVector;',
  '⥒': '&LeftVectorBar;',
  '⋚': '&LessEqualGreater;',
  '≦': '&LessFullEqual;',
  '≶': '&LessGreater;',
  '⪡': '&LessLess;',
  '⩽': '&LessSlantEqual;',
  '≲': '&LessTilde;',
  '𝔏': '&Lfr;',
  '⋘': '&Ll;',
  '⇚': '&Lleftarrow;',
  'Ŀ': '&Lmidot;',
  '⟵': '&LongLeftArrow;',
  '⟷': '&LongLeftRightArrow;',
  '⟶': '&LongRightArrow;',
  '𝕃': '&Lopf;',
  '↙': '&LowerLeftArrow;',
  '↘': '&LowerRightArrow;',
  '↰': '&Lsh;',
  'Ł': '&Lstrok;',
  '≪': '&Lt;',
  '⤅': '&Map;',
  'М': '&Mcy;',
  ' ': '&MediumSpace;',
  'ℳ': '&Mellintrf;',
  '𝔐': '&Mfr;',
  '∓': '&MinusPlus;',
  '𝕄': '&Mopf;',
  'Μ': '&Mu;',
  'Њ': '&NJcy;',
  'Ń': '&Nacute;',
  'Ň': '&Ncaron;',
  'Ņ': '&Ncedil;',
  'Н': '&Ncy;',
  '​': '&NegativeMediumSpace;',
  '\n': '&NewLine;',
  '𝔑': '&Nfr;',
  '⁠': '&NoBreak;',
  ' ': '&NonBreakingSpace;',
  'ℕ': '&Nopf;',
  '⫬': '&Not;',
  '≢': '&NotCongruent;',
  '≭': '&NotCupCap;',
  '∦': '&NotDoubleVerticalBar;',
  '∉': '&NotElement;',
  '≠': '&NotEqual;',
  '≂̸': '&NotEqualTilde;',
  '∄': '&NotExists;',
  '≯': '&NotGreater;',
  '≱': '&NotGreaterEqual;',
  '≧̸': '&NotGreaterFullEqual;',
  '≫̸': '&NotGreaterGreater;',
  '≹': '&NotGreaterLess;',
  '⩾̸': '&NotGreaterSlantEqual;',
  '≵': '&NotGreaterTilde;',
  '≎̸': '&NotHumpDownHump;',
  '≏̸': '&NotHumpEqual;',
  '⋪': '&NotLeftTriangle;',
  '⧏̸': '&NotLeftTriangleBar;',
  '⋬': '&NotLeftTriangleEqual;',
  '≮': '&NotLess;',
  '≰': '&NotLessEqual;',
  '≸': '&NotLessGreater;',
  '≪̸': '&NotLessLess;',
  '⩽̸': '&NotLessSlantEqual;',
  '≴': '&NotLessTilde;',
  '⪢̸': '&NotNestedGreaterGreater;',
  '⪡̸': '&NotNestedLessLess;',
  '⊀': '&NotPrecedes;',
  '⪯̸': '&NotPrecedesEqual;',
  '⋠': '&NotPrecedesSlantEqual;',
  '∌': '&NotReverseElement;',
  '⋫': '&NotRightTriangle;',
  '⧐̸': '&NotRightTriangleBar;',
  '⋭': '&NotRightTriangleEqual;',
  '⊏̸': '&NotSquareSubset;',
  '⋢': '&NotSquareSubsetEqual;',
  '⊐̸': '&NotSquareSuperset;',
  '⋣': '&NotSquareSupersetEqual;',
  '⊂⃒': '&NotSubset;',
  '⊈': '&NotSubsetEqual;',
  '⊁': '&NotSucceeds;',
  '⪰̸': '&NotSucceedsEqual;',
  '⋡': '&NotSucceedsSlantEqual;',
  '≿̸': '&NotSucceedsTilde;',
  '⊃⃒': '&NotSuperset;',
  '⊉': '&NotSupersetEqual;',
  '≁': '&NotTilde;',
  '≄': '&NotTildeEqual;',
  '≇': '&NotTildeFullEqual;',
  '≉': '&NotTildeTilde;',
  '∤': '&NotVerticalBar;',
  '𝒩': '&Nscr;',
  'Ñ': '&Ntilde;',
  'Ν': '&Nu;',
  'Œ': '&OElig;',
  'Ó': '&Oacute;',
  'Ô': '&Ocirc;',
  'О': '&Ocy;',
  'Ő': '&Odblac;',
  '𝔒': '&Ofr;',
  'Ò': '&Ograve;',
  'Ō': '&Omacr;',
  'Ω': '&Omega;',
  'Ο': '&Omicron;',
  '𝕆': '&Oopf;',
  '“': '&OpenCurlyDoubleQuote;',
  '‘': '&OpenCurlyQuote;',
  '⩔': '&Or;',
  '𝒪': '&Oscr;',
  'Ø': '&Oslash;',
  'Õ': '&Otilde;',
  '⨷': '&Otimes;',
  'Ö': '&Ouml;',
  '‾': '&OverBar;',
  '⏞': '&OverBrace;',
  '⎴': '&OverBracket;',
  '⏜': '&OverParenthesis;',
  '∂': '&PartialD;',
  'П': '&Pcy;',
  '𝔓': '&Pfr;',
  'Φ': '&Phi;',
  'Π': '&Pi;',
  '±': '&PlusMinus;',
  'ℙ': '&Popf;',
  '⪻': '&Pr;',
  '≺': '&Precedes;',
  '⪯': '&PrecedesEqual;',
  '≼': '&PrecedesSlantEqual;',
  '≾': '&PrecedesTilde;',
  '″': '&Prime;',
  '∏': '&Product;',
  '∝': '&Proportional;',
  '𝒫': '&Pscr;',
  'Ψ': '&Psi;',
  '"': '&QUOT;',
  '𝔔': '&Qfr;',
  'ℚ': '&Qopf;',
  '𝒬': '&Qscr;',
  '⤐': '&RBarr;',
  '®': '&REG;',
  'Ŕ': '&Racute;',
  '⟫': '&Rang;',
  '↠': '&Rarr;',
  '⤖': '&Rarrtl;',
  'Ř': '&Rcaron;',
  'Ŗ': '&Rcedil;',
  'Р': '&Rcy;',
  'ℜ': '&Re;',
  '∋': '&ReverseElement;',
  '⇋': '&ReverseEquilibrium;',
  '⥯': '&ReverseUpEquilibrium;',
  'Ρ': '&Rho;',
  '⟩': '&RightAngleBracket;',
  '→': '&RightArrow;',
  '⇥': '&RightArrowBar;',
  '⇄': '&RightArrowLeftArrow;',
  '⌉': '&RightCeiling;',
  '⟧': '&RightDoubleBracket;',
  '⥝': '&RightDownTeeVector;',
  '⇂': '&RightDownVector;',
  '⥕': '&RightDownVectorBar;',
  '⌋': '&RightFloor;',
  '⊢': '&RightTee;',
  '↦': '&RightTeeArrow;',
  '⥛': '&RightTeeVector;',
  '⊳': '&RightTriangle;',
  '⧐': '&RightTriangleBar;',
  '⊵': '&RightTriangleEqual;',
  '⥏': '&RightUpDownVector;',
  '⥜': '&RightUpTeeVector;',
  '↾': '&RightUpVector;',
  '⥔': '&RightUpVectorBar;',
  '⇀': '&RightVector;',
  '⥓': '&RightVectorBar;',
  'ℝ': '&Ropf;',
  '⥰': '&RoundImplies;',
  '⇛': '&Rrightarrow;',
  'ℛ': '&Rscr;',
  '↱': '&Rsh;',
  '⧴': '&RuleDelayed;',
  'Щ': '&SHCHcy;',
  'Ш': '&SHcy;',
  'Ь': '&SOFTcy;',
  'Ś': '&Sacute;',
  '⪼': '&Sc;',
  'Š': '&Scaron;',
  'Ş': '&Scedil;',
  'Ŝ': '&Scirc;',
  'С': '&Scy;',
  '𝔖': '&Sfr;',
  '↑': '&ShortUpArrow;',
  'Σ': '&Sigma;',
  '∘': '&SmallCircle;',
  '𝕊': '&Sopf;',
  '√': '&Sqrt;',
  '□': '&Square;',
  '⊓': '&SquareIntersection;',
  '⊏': '&SquareSubset;',
  '⊑': '&SquareSubsetEqual;',
  '⊐': '&SquareSuperset;',
  '⊒': '&SquareSupersetEqual;',
  '⊔': '&SquareUnion;',
  '𝒮': '&Sscr;',
  '⋆': '&Star;',
  '⋐': '&Sub;',
  '⊆': '&SubsetEqual;',
  '≻': '&Succeeds;',
  '⪰': '&SucceedsEqual;',
  '≽': '&SucceedsSlantEqual;',
  '≿': '&SucceedsTilde;',
  '∑': '&Sum;',
  '⋑': '&Sup;',
  '⊃': '&Superset;',
  '⊇': '&SupersetEqual;',
  'Þ': '&THORN;',
  '™': '&TRADE;',
  'Ћ': '&TSHcy;',
  'Ц': '&TScy;',
  '\t': '&Tab;',
  'Τ': '&Tau;',
  'Ť': '&Tcaron;',
  'Ţ': '&Tcedil;',
  'Т': '&Tcy;',
  '𝔗': '&Tfr;',
  '∴': '&Therefore;',
  'Θ': '&Theta;',
  '  ': '&ThickSpace;',
  ' ': '&ThinSpace;',
  '∼': '&Tilde;',
  '≃': '&TildeEqual;',
  '≅': '&TildeFullEqual;',
  '≈': '&TildeTilde;',
  '𝕋': '&Topf;',
  '⃛': '&TripleDot;',
  '𝒯': '&Tscr;',
  'Ŧ': '&Tstrok;',
  'Ú': '&Uacute;',
  '↟': '&Uarr;',
  '⥉': '&Uarrocir;',
  'Ў': '&Ubrcy;',
  'Ŭ': '&Ubreve;',
  'Û': '&Ucirc;',
  'У': '&Ucy;',
  'Ű': '&Udblac;',
  '𝔘': '&Ufr;',
  'Ù': '&Ugrave;',
  'Ū': '&Umacr;',
  '_': '&UnderBar;',
  '⏟': '&UnderBrace;',
  '⎵': '&UnderBracket;',
  '⏝': '&UnderParenthesis;',
  '⋃': '&Union;',
  '⊎': '&UnionPlus;',
  'Ų': '&Uogon;',
  '𝕌': '&Uopf;',
  '⤒': '&UpArrowBar;',
  '⇅': '&UpArrowDownArrow;',
  '↕': '&UpDownArrow;',
  '⥮': '&UpEquilibrium;',
  '⊥': '&UpTee;',
  '↥': '&UpTeeArrow;',
  '↖': '&UpperLeftArrow;',
  '↗': '&UpperRightArrow;',
  'ϒ': '&Upsi;',
  'Υ': '&Upsilon;',
  'Ů': '&Uring;',
  '𝒰': '&Uscr;',
  'Ũ': '&Utilde;',
  'Ü': '&Uuml;',
  '⊫': '&VDash;',
  '⫫': '&Vbar;',
  'В': '&Vcy;',
  '⊩': '&Vdash;',
  '⫦': '&Vdashl;',
  '⋁': '&Vee;',
  '‖': '&Verbar;',
  '∣': '&VerticalBar;',
  '|': '&VerticalLine;',
  '❘': '&VerticalSeparator;',
  '≀': '&VerticalTilde;',
  ' ': '&VeryThinSpace;',
  '𝔙': '&Vfr;',
  '𝕍': '&Vopf;',
  '𝒱': '&Vscr;',
  '⊪': '&Vvdash;',
  'Ŵ': '&Wcirc;',
  '⋀': '&Wedge;',
  '𝔚': '&Wfr;',
  '𝕎': '&Wopf;',
  '𝒲': '&Wscr;',
  '𝔛': '&Xfr;',
  'Ξ': '&Xi;',
  '𝕏': '&Xopf;',
  '𝒳': '&Xscr;',
  'Я': '&YAcy;',
  'Ї': '&YIcy;',
  'Ю': '&YUcy;',
  'Ý': '&Yacute;',
  'Ŷ': '&Ycirc;',
  'Ы': '&Ycy;',
  '𝔜': '&Yfr;',
  '𝕐': '&Yopf;',
  '𝒴': '&Yscr;',
  'Ÿ': '&Yuml;',
  'Ж': '&ZHcy;',
  'Ź': '&Zacute;',
  'Ž': '&Zcaron;',
  'З': '&Zcy;',
  'Ż': '&Zdot;',
  'Ζ': '&Zeta;',
  'ℨ': '&Zfr;',
  'ℤ': '&Zopf;',
  '𝒵': '&Zscr;',
  'á': '&aacute;',
  'ă': '&abreve;',
  '∾': '&ac;',
  '∾̳': '&acE;',
  '∿': '&acd;',
  'â': '&acirc;',
  'а': '&acy;',
  'æ': '&aelig;',
  '𝔞': '&afr;',
  'à': '&agrave;',
  'ℵ': '&alefsym;',
  'α': '&alpha;',
  'ā': '&amacr;',
  '⨿': '&amalg;',
  '∧': '&and;',
  '⩕': '&andand;',
  '⩜': '&andd;',
  '⩘': '&andslope;',
  '⩚': '&andv;',
  '∠': '&ang;',
  '⦤': '&ange;',
  '∡': '&angmsd;',
  '⦨': '&angmsdaa;',
  '⦩': '&angmsdab;',
  '⦪': '&angmsdac;',
  '⦫': '&angmsdad;',
  '⦬': '&angmsdae;',
  '⦭': '&angmsdaf;',
  '⦮': '&angmsdag;',
  '⦯': '&angmsdah;',
  '∟': '&angrt;',
  '⊾': '&angrtvb;',
  '⦝': '&angrtvbd;',
  '∢': '&angsph;',
  '⍼': '&angzarr;',
  'ą': '&aogon;',
  '𝕒': '&aopf;',
  '⩰': '&apE;',
  '⩯': '&apacir;',
  '≊': '&ape;',
  '≋': '&apid;',
  '\'': '&apos;',
  'å': '&aring;',
  '𝒶': '&ascr;',
  '*': '&ast;',
  'ã': '&atilde;',
  'ä': '&auml;',
  '⨑': '&awint;',
  '⫭': '&bNot;',
  '≌': '&backcong;',
  '϶': '&backepsilon;',
  '‵': '&backprime;',
  '∽': '&backsim;',
  '⋍': '&backsimeq;',
  '⊽': '&barvee;',
  '⌅': '&barwed;',
  '⎶': '&bbrktbrk;',
  'б': '&bcy;',
  '„': '&bdquo;',
  '⦰': '&bemptyv;',
  'β': '&beta;',
  'ℶ': '&beth;',
  '≬': '&between;',
  '𝔟': '&bfr;',
  '◯': '&bigcirc;',
  '⨀': '&bigodot;',
  '⨁': '&bigoplus;',
  '⨂': '&bigotimes;',
  '⨆': '&bigsqcup;',
  '★': '&bigstar;',
  '▽': '&bigtriangledown;',
  '△': '&bigtriangleup;',
  '⨄': '&biguplus;',
  '⤍': '&bkarow;',
  '⧫': '&blacklozenge;',
  '▴': '&blacktriangle;',
  '▾': '&blacktriangledown;',
  '◂': '&blacktriangleleft;',
  '▸': '&blacktriangleright;',
  '␣': '&blank;',
  '▒': '&blk12;',
  '░': '&blk14;',
  '▓': '&blk34;',
  '█': '&block;',
  '=⃥': '&bne;',
  '≡⃥': '&bnequiv;',
  '⌐': '&bnot;',
  '𝕓': '&bopf;',
  '⋈': '&bowtie;',
  '╗': '&boxDL;',
  '╔': '&boxDR;',
  '╖': '&boxDl;',
  '╓': '&boxDr;',
  '═': '&boxH;',
  '╦': '&boxHD;',
  '╩': '&boxHU;',
  '╤': '&boxHd;',
  '╧': '&boxHu;',
  '╝': '&boxUL;',
  '╚': '&boxUR;',
  '╜': '&boxUl;',
  '╙': '&boxUr;',
  '║': '&boxV;',
  '╬': '&boxVH;',
  '╣': '&boxVL;',
  '╠': '&boxVR;',
  '╫': '&boxVh;',
  '╢': '&boxVl;',
  '╟': '&boxVr;',
  '⧉': '&boxbox;',
  '╕': '&boxdL;',
  '╒': '&boxdR;',
  '┐': '&boxdl;',
  '┌': '&boxdr;',
  '╥': '&boxhD;',
  '╨': '&boxhU;',
  '┬': '&boxhd;',
  '┴': '&boxhu;',
  '⊟': '&boxminus;',
  '⊞': '&boxplus;',
  '⊠': '&boxtimes;',
  '╛': '&boxuL;',
  '╘': '&boxuR;',
  '┘': '&boxul;',
  '└': '&boxur;',
  '│': '&boxv;',
  '╪': '&boxvH;',
  '╡': '&boxvL;',
  '╞': '&boxvR;',
  '┼': '&boxvh;',
  '┤': '&boxvl;',
  '├': '&boxvr;',
  '¦': '&brvbar;',
  '𝒷': '&bscr;',
  '⁏': '&bsemi;',
  '\\': '&bsol;',
  '⧅': '&bsolb;',
  '⟈': '&bsolhsub;',
  '•': '&bull;',
  '⪮': '&bumpE;',
  'ć': '&cacute;',
  '∩': '&cap;',
  '⩄': '&capand;',
  '⩉': '&capbrcup;',
  '⩋': '&capcap;',
  '⩇': '&capcup;',
  '⩀': '&capdot;',
  '∩︀': '&caps;',
  '⁁': '&caret;',
  '⩍': '&ccaps;',
  'č': '&ccaron;',
  'ç': '&ccedil;',
  'ĉ': '&ccirc;',
  '⩌': '&ccups;',
  '⩐': '&ccupssm;',
  'ċ': '&cdot;',
  '⦲': '&cemptyv;',
  '¢': '&cent;',
  '𝔠': '&cfr;',
  'ч': '&chcy;',
  '✓': '&check;',
  'χ': '&chi;',
  '○': '&cir;',
  '⧃': '&cirE;',
  'ˆ': '&circ;',
  '≗': '&circeq;',
  '↺': '&circlearrowleft;',
  '↻': '&circlearrowright;',
  'Ⓢ': '&circledS;',
  '⊛': '&circledast;',
  '⊚': '&circledcirc;',
  '⊝': '&circleddash;',
  '⨐': '&cirfnint;',
  '⫯': '&cirmid;',
  '⧂': '&cirscir;',
  '♣': '&clubs;',
  ':': '&colon;',
  ',': '&comma;',
  '@': '&commat;',
  '∁': '&comp;',
  '⩭': '&congdot;',
  '𝕔': '&copf;',
  '℗': '&copysr;',
  '↵': '&crarr;',
  '✗': '&cross;',
  '𝒸': '&cscr;',
  '⫏': '&csub;',
  '⫑': '&csube;',
  '⫐': '&csup;',
  '⫒': '&csupe;',
  '⋯': '&ctdot;',
  '⤸': '&cudarrl;',
  '⤵': '&cudarrr;',
  '⋞': '&cuepr;',
  '⋟': '&cuesc;',
  '↶': '&cularr;',
  '⤽': '&cularrp;',
  '∪': '&cup;',
  '⩈': '&cupbrcap;',
  '⩆': '&cupcap;',
  '⩊': '&cupcup;',
  '⊍': '&cupdot;',
  '⩅': '&cupor;',
  '∪︀': '&cups;',
  '↷': '&curarr;',
  '⤼': '&curarrm;',
  '⋎': '&curlyvee;',
  '⋏': '&curlywedge;',
  '¤': '&curren;',
  '∱': '&cwint;',
  '⌭': '&cylcty;',
  '⥥': '&dHar;',
  '†': '&dagger;',
  'ℸ': '&daleth;',
  '‐': '&dash;',
  '⤏': '&dbkarow;',
  'ď': '&dcaron;',
  'д': '&dcy;',
  '⇊': '&ddarr;',
  '⩷': '&ddotseq;',
  '°': '&deg;',
  'δ': '&delta;',
  '⦱': '&demptyv;',
  '⥿': '&dfisht;',
  '𝔡': '&dfr;',
  '♦': '&diamondsuit;',
  'ϝ': '&digamma;',
  '⋲': '&disin;',
  '÷': '&div;',
  '⋇': '&divideontimes;',
  'ђ': '&djcy;',
  '⌞': '&dlcorn;',
  '⌍': '&dlcrop;',
  '$': '&dollar;',
  '𝕕': '&dopf;',
  '≑': '&doteqdot;',
  '∸': '&dotminus;',
  '∔': '&dotplus;',
  '⊡': '&dotsquare;',
  '⌟': '&drcorn;',
  '⌌': '&drcrop;',
  '𝒹': '&dscr;',
  'ѕ': '&dscy;',
  '⧶': '&dsol;',
  'đ': '&dstrok;',
  '⋱': '&dtdot;',
  '⦦': '&dwangle;',
  'џ': '&dzcy;',
  '⩮': '&easter;',
  'ě': '&ecaron;',
  '≖': '&ecir;',
  '≕': '&ecolon;',
  'э': '&ecy;',
  '≒': '&efDot;',
  '𝔢': '&efr;',
  '⪚': '&eg;',
  '⪖': '&egs;',
  '⪘': '&egsdot;',
  '⪙': '&el;',
  '⏧': '&elinters;',
  'ℓ': '&ell;',
  '⪕': '&els;',
  '⪗': '&elsdot;',
  'ē': '&emacr;',
  ' ': '&emsp13;',
  ' ': '&emsp14;',
  ' ': '&emsp;',
  'ŋ': '&eng;',
  ' ': '&ensp;',
  'ę': '&eogon;',
  '𝕖': '&eopf;',
  '⋕': '&epar;',
  '⧣': '&eparsl;',
  '⩱': '&eplus;',
  'ε': '&epsi;',
  'ϵ': '&epsiv;',
  '=': '&equals;',
  '≟': '&equest;',
  '⩸': '&equivDD;',
  '⧥': '&eqvparsl;',
  '≓': '&erDot;',
  '⥱': '&erarr;',
  'ℯ': '&escr;',
  'η': '&eta;',
  'ð': '&eth;',
  'ë': '&euml;',
  '€': '&euro;',
  '!': '&excl;',
  'ф': '&fcy;',
  '♀': '&female;',
  'ﬃ': '&ffilig;',
  'ﬀ': '&fflig;',
  'ﬄ': '&ffllig;',
  '𝔣': '&ffr;',
  'ﬁ': '&filig;',
  'fj': '&fjlig;',
  '♭': '&flat;',
  'ﬂ': '&fllig;',
  '▱': '&fltns;',
  'ƒ': '&fnof;',
  '𝕗': '&fopf;',
  '⋔': '&fork;',
  '⫙': '&forkv;',
  '⨍': '&fpartint;',
  '½': '&frac12;',
  '⅓': '&frac13;',
  '¼': '&frac14;',
  '⅕': '&frac15;',
  '⅙': '&frac16;',
  '⅛': '&frac18;',
  '⅔': '&frac23;',
  '⅖': '&frac25;',
  '¾': '&frac34;',
  '⅗': '&frac35;',
  '⅜': '&frac38;',
  '⅘': '&frac45;',
  '⅚': '&frac56;',
  '⅝': '&frac58;',
  '⅞': '&frac78;',
  '⁄': '&frasl;',
  '⌢': '&frown;',
  '𝒻': '&fscr;',
  'é': '&eacute;',
  '⪌': '&gEl;',
  'ǵ': '&gacute;',
  'γ': '&gamma;',
  '⪆': '&gap;',
  'ğ': '&gbreve;',
  'ĝ': '&gcirc;',
  'г': '&gcy;',
  'ġ': '&gdot;',
  '⪩': '&gescc;',
  '⪀': '&gesdot;',
  '⪂': '&gesdoto;',
  '⪄': '&gesdotol;',
  '⋛︀': '&gesl;',
  '⪔': '&gesles;',
  '𝔤': '&gfr;',
  'ℷ': '&gimel;',
  'ѓ': '&gjcy;',
  '⪒': '&glE;',
  '⪥': '&gla;',
  '⪤': '&glj;',
  '≩': '&gnE;',
  '⪊': '&gnap;',
  '⪈': '&gne;',
  '⋧': '&gnsim;',
  '𝕘': '&gopf;',
  'ℊ': '&gscr;',
  '⪎': '&gsime;',
  '⪐': '&gsiml;',
  '⪧': '&gtcc;',
  '⩺': '&gtcir;',
  '⋗': '&gtdot;',
  '⦕': '&gtlPar;',
  '⩼': '&gtquest;',
  '⥸': '&gtrarr;',
  '≩︀': '&gvertneqq;',
  'ъ': '&hardcy;',
  '⥈': '&harrcir;',
  '↭': '&harrw;',
  'ℏ': '&hbar;',
  'ĥ': '&hcirc;',
  '♥': '&hearts;',
  '…': '&hellip;',
  '⊹': '&hercon;',
  '𝔥': '&hfr;',
  '⤥': '&hksearow;',
  '⤦': '&hkswarow;',
  '⇿': '&hoarr;',
  '∻': '&homtht;',
  '↩': '&hookleftarrow;',
  '↪': '&hookrightarrow;',
  '𝕙': '&hopf;',
  '―': '&horbar;',
  '𝒽': '&hscr;',
  'ħ': '&hstrok;',
  '⁃': '&hybull;',
  'í': '&iacute;',
  'î': '&icirc;',
  'и': '&icy;',
  'е': '&iecy;',
  '¡': '&iexcl;',
  '𝔦': '&ifr;',
  'ì': '&igrave;',
  '⨌': '&iiiint;',
  '∭': '&iiint;',
  '⧜': '&iinfin;',
  '℩': '&iiota;',
  'ĳ': '&ijlig;',
  'ī': '&imacr;',
  'ı': '&imath;',
  '⊷': '&imof;',
  'Ƶ': '&imped;',
  '℅': '&incare;',
  '∞': '&infin;',
  '⧝': '&infintie;',
  '⊺': '&intcal;',
  '⨗': '&intlarhk;',
  '⨼': '&intprod;',
  'ё': '&iocy;',
  'į': '&iogon;',
  '𝕚': '&iopf;',
  'ι': '&iota;',
  '¿': '&iquest;',
  '𝒾': '&iscr;',
  '⋹': '&isinE;',
  '⋵': '&isindot;',
  '⋴': '&isins;',
  '⋳': '&isinsv;',
  'ĩ': '&itilde;',
  'і': '&iukcy;',
  'ï': '&iuml;',
  'ĵ': '&jcirc;',
  'й': '&jcy;',
  '𝔧': '&jfr;',
  'ȷ': '&jmath;',
  '𝕛': '&jopf;',
  '𝒿': '&jscr;',
  'ј': '&jsercy;',
  'є': '&jukcy;',
  'κ': '&kappa;',
  'ϰ': '&kappav;',
  'ķ': '&kcedil;',
  'к': '&kcy;',
  '𝔨': '&kfr;',
  'ĸ': '&kgreen;',
  'х': '&khcy;',
  'ќ': '&kjcy;',
  '𝕜': '&kopf;',
  '𝓀': '&kscr;',
  '⤛': '&lAtail;',
  '⤎': '&lBarr;',
  '⪋': '&lEg;',
  '⥢': '&lHar;',
  'ĺ': '&lacute;',
  '⦴': '&laemptyv;',
  'λ': '&lambda;',
  '⦑': '&langd;',
  '⪅': '&lap;',
  '«': '&laquo;',
  '⤟': '&larrbfs;',
  '⤝': '&larrfs;',
  '↫': '&larrlp;',
  '⤹': '&larrpl;',
  '⥳': '&larrsim;',
  '↢': '&larrtl;',
  '⪫': '&lat;',
  '⤙': '&latail;',
  '⪭': '&late;',
  '⪭︀': '&lates;',
  '⤌': '&lbarr;',
  '❲': '&lbbrk;',
  '{': '&lbrace;',
  '[': '&lbrack;',
  '⦋': '&lbrke;',
  '⦏': '&lbrksld;',
  '⦍': '&lbrkslu;',
  'ľ': '&lcaron;',
  'ļ': '&lcedil;',
  'л': '&lcy;',
  '⤶': '&ldca;',
  '⥧': '&ldrdhar;',
  '⥋': '&ldrushar;',
  '↲': '&ldsh;',
  '≤': '&le;',
  '⇇': '&leftleftarrows;',
  '⋋': '&leftthreetimes;',
  '⪨': '&lescc;',
  '⩿': '&lesdot;',
  '⪁': '&lesdoto;',
  '⪃': '&lesdotor;',
  '⋚︀': '&lesg;',
  '⪓': '&lesges;',
  '⋖': '&lessdot;',
  '⥼': '&lfisht;',
  '𝔩': '&lfr;',
  '⪑': '&lgE;',
  '⥪': '&lharul;',
  '▄': '&lhblk;',
  'љ': '&ljcy;',
  '⥫': '&llhard;',
  '◺': '&lltri;',
  'ŀ': '&lmidot;',
  '⎰': '&lmoust;',
  '≨': '&lnE;',
  '⪉': '&lnap;',
  '⪇': '&lne;',
  '⋦': '&lnsim;',
  '⟬': '&loang;',
  '⇽': '&loarr;',
  '↬': '&looparrowright;',
  '⦅': '&lopar;',
  '𝕝': '&lopf;',
  '⨭': '&loplus;',
  '⨴': '&lotimes;',
  '∗': '&lowast;',
  '◊': '&loz;',
  '(': '&lpar;',
  '⦓': '&lparlt;',
  '⥭': '&lrhard;',
  '‎': '&lrm;',
  '⊿': '&lrtri;',
  '‹': '&lsaquo;',
  '𝓁': '&lscr;',
  '⪍': '&lsime;',
  '⪏': '&lsimg;',
  '‚': '&lsquor;',
  'ł': '&lstrok;',
  '⪦': '&ltcc;',
  '⩹': '&ltcir;',
  '⋉': '&ltimes;',
  '⥶': '&ltlarr;',
  '⩻': '&ltquest;',
  '⦖': '&ltrPar;',
  '◃': '&ltri;',
  '⥊': '&lurdshar;',
  '⥦': '&luruhar;',
  '≨︀': '&lvertneqq;',
  '∺': '&mDDot;',
  '¯': '&macr;',
  '♂': '&male;',
  '✠': '&malt;',
  '▮': '&marker;',
  '⨩': '&mcomma;',
  'м': '&mcy;',
  '—': '&mdash;',
  '𝔪': '&mfr;',
  '℧': '&mho;',
  'µ': '&micro;',
  '⫰': '&midcir;',
  '−': '&minus;',
  '⨪': '&minusdu;',
  '⫛': '&mlcp;',
  '⊧': '&models;',
  '𝕞': '&mopf;',
  '𝓂': '&mscr;',
  'μ': '&mu;',
  '⊸': '&multimap;',
  '⋙̸': '&nGg;',
  '≫⃒': '&nGt;',
  '⇍': '&nLeftarrow;',
  '⇎': '&nLeftrightarrow;',
  '⋘̸': '&nLl;',
  '≪⃒': '&nLt;',
  '⇏': '&nRightarrow;',
  '⊯': '&nVDash;',
  '⊮': '&nVdash;',
  'ń': '&nacute;',
  '∠⃒': '&nang;',
  '⩰̸': '&napE;',
  '≋̸': '&napid;',
  'ŉ': '&napos;',
  '♮': '&natur;',
  '⩃': '&ncap;',
  'ň': '&ncaron;',
  'ņ': '&ncedil;',
  '⩭̸': '&ncongdot;',
  '⩂': '&ncup;',
  'н': '&ncy;',
  '–': '&ndash;',
  '⇗': '&neArr;',
  '⤤': '&nearhk;',
  '≐̸': '&nedot;',
  '⤨': '&nesear;',
  '𝔫': '&nfr;',
  '↮': '&nharr;',
  '⫲': '&nhpar;',
  '⋼': '&nis;',
  '⋺': '&nisd;',
  'њ': '&njcy;',
  '≦̸': '&nlE;',
  '↚': '&nlarr;',
  '‥': '&nldr;',
  '𝕟': '&nopf;',
  '¬': '&not;',
  '⋹̸': '&notinE;',
  '⋵̸': '&notindot;',
  '⋷': '&notinvb;',
  '⋶': '&notinvc;',
  '⋾': '&notnivb;',
  '⋽': '&notnivc;',
  '⫽⃥': '&nparsl;',
  '∂̸': '&npart;',
  '⨔': '&npolint;',
  '↛': '&nrarr;',
  '⤳̸': '&nrarrc;',
  '↝̸': '&nrarrw;',
  '𝓃': '&nscr;',
  '⊄': '&nsub;',
  '⫅̸': '&nsubE;',
  '⊅': '&nsup;',
  '⫆̸': '&nsupE;',
  'ν': '&nu;',
  '#': '&num;',
  '№': '&numero;',
  ' ': '&numsp;',
  '⊭': '&nvDash;',
  '⤄': '&nvHarr;',
  '≍⃒': '&nvap;',
  '⊬': '&nvdash;',
  '≥⃒': '&nvge;',
  '>⃒': '&nvgt;',
  '⧞': '&nvinfin;',
  '⤂': '&nvlArr;',
  '≤⃒': '&nvle;',
  '<⃒': '&nvlt;',
  '⊴⃒': '&nvltrie;',
  '⤃': '&nvrArr;',
  '⊵⃒': '&nvrtrie;',
  '∼⃒': '&nvsim;',
  '⇖': '&nwArr;',
  '⤣': '&nwarhk;',
  '⤧': '&nwnear;',
  'ó': '&oacute;',
  'ô': '&ocirc;',
  'о': '&ocy;',
  'ő': '&odblac;',
  '⨸': '&odiv;',
  '⦼': '&odsold;',
  'œ': '&oelig;',
  '⦿': '&ofcir;',
  '𝔬': '&ofr;',
  '˛': '&ogon;',
  'ò': '&ograve;',
  '⧁': '&ogt;',
  '⦵': '&ohbar;',
  '⦾': '&olcir;',
  '⦻': '&olcross;',
  '⧀': '&olt;',
  'ō': '&omacr;',
  'ω': '&omega;',
  'ο': '&omicron;',
  '⦶': '&omid;',
  '𝕠': '&oopf;',
  '⦷': '&opar;',
  '⦹': '&operp;',
  '∨': '&or;',
  '⩝': '&ord;',
  'ℴ': '&order;',
  'ª': '&ordf;',
  'º': '&ordm;',
  '⊶': '&origof;',
  '⩖': '&oror;',
  '⩗': '&orslope;',
  '⊘': '&osol;',
  '⨶': '&otimesas;',
  '⫳': '&parsim;',
  'п': '&pcy;',
  '%': '&percnt;',
  '.': '&period;',
  '‱': '&pertenk;',
  '𝔭': '&pfr;',
  'φ': '&phi;',
  '☎': '&phone;',
  '+': '&plus;',
  '⨥': '&plusdu;',
  '⩲': '&pluse;',
  '⨦': '&plussim;',
  '⨧': '&plustwo;',
  '⨕': '&pointint;',
  '𝕡': '&popf;',
  '£': '&pound;',
  '⪳': '&prE;',
  '⪷': '&prap;',
  '⪹': '&precnapprox;',
  '⪵': '&precneqq;',
  '⋨': '&precnsim;',
  '′': '&prime;',
  '⌮': '&profalar;',
  '⌒': '&profline;',
  '⌓': '&profsurf;',
  '⊰': '&prurel;',
  '𝓅': '&pscr;',
  'ψ': '&psi;',
  ' ': '&puncsp;',
  '𝔮': '&qfr;',
  '𝕢': '&qopf;',
  '⁗': '&qprime;',
  '𝓆': '&qscr;',
  '⨖': '&quatint;',
  '?': '&quest;',
  '⤜': '&rAtail;',
  '⥤': '&rHar;',
  '∽̱': '&race;',
  'ŕ': '&racute;',
  '⦳': '&raemptyv;',
  '⦒': '&rangd;',
  '⦥': '&range;',
  '»': '&raquo;',
  '⥵': '&rarrap;',
  '⤠': '&rarrbfs;',
  '⤳': '&rarrc;',
  '⤞': '&rarrfs;',
  '⥅': '&rarrpl;',
  '⥴': '&rarrsim;',
  '↣': '&rarrtl;',
  '↝': '&rarrw;',
  '⤚': '&ratail;',
  '∶': '&ratio;',
  '❳': '&rbbrk;',
  '}': '&rbrace;',
  ']': '&rbrack;',
  '⦌': '&rbrke;',
  '⦎': '&rbrksld;',
  '⦐': '&rbrkslu;',
  'ř': '&rcaron;',
  'ŗ': '&rcedil;',
  'р': '&rcy;',
  '⤷': '&rdca;',
  '⥩': '&rdldhar;',
  '↳': '&rdsh;',
  '▭': '&rect;',
  '⥽': '&rfisht;',
  '𝔯': '&rfr;',
  '⥬': '&rharul;',
  'ρ': '&rho;',
  'ϱ': '&rhov;',
  '⇉': '&rightrightarrows;',
  '⋌': '&rightthreetimes;',
  '˚': '&ring;',
  '‏': '&rlm;',
  '⎱': '&rmoust;',
  '⫮': '&rnmid;',
  '⟭': '&roang;',
  '⇾': '&roarr;',
  '⦆': '&ropar;',
  '𝕣': '&ropf;',
  '⨮': '&roplus;',
  '⟼': '&longmapsto;',
  '⨵': '&rotimes;',
  ')': '&rpar;',
  '⦔': '&rpargt;',
  '⨒': '&rppolint;',
  '›': '&rsaquo;',
  '𝓇': '&rscr;',
  '⋊': '&rtimes;',
  '▹': '&rtri;',
  '⧎': '&rtriltri;',
  '⥨': '&ruluhar;',
  '℞': '&rx;',
  'ś': '&sacute;',
  '⪴': '&scE;',
  '⪸': '&scap;',
  'š': '&scaron;',
  'ş': '&scedil;',
  'ŝ': '&scirc;',
  '⪶': '&scnE;',
  '⪺': '&scnap;',
  '⋩': '&scnsim;',
  '⨓': '&scpolint;',
  'с': '&scy;',
  '⋅': '&sdot;',
  '⩦': '&sdote;',
  '⇘': '&seArr;',
  '§': '&sect;',
  ';': '&semi;',
  '⤩': '&seswar;',
  '✶': '&sext;',
  '𝔰': '&sfr;',
  '♯': '&sharp;',
  'щ': '&shchcy;',
  'ш': '&shcy;',
  '­': '&shy;',
  'σ': '&sigma;',
  'ς': '&sigmaf;',
  '⩪': '&simdot;',
  '⪞': '&simg;',
  '⪠': '&simgE;',
  '⪝': '&siml;',
  '⪟': '&simlE;',
  '≆': '&simne;',
  '⨤': '&simplus;',
  '⥲': '&simrarr;',
  '⨳': '&smashp;',
  '⧤': '&smeparsl;',
  '⌣': '&smile;',
  '⪪': '&smt;',
  '⪬': '&smte;',
  '⪬︀': '&smtes;',
  'ь': '&softcy;',
  '/': '&sol;',
  '⧄': '&solb;',
  '⌿': '&solbar;',
  '𝕤': '&sopf;',
  '♠': '&spades;',
  '⊓︀': '&sqcaps;',
  '⊔︀': '&sqcups;',
  '𝓈': '&sscr;',
  '☆': '&star;',
  'ϕ': '&straightphi;',
  '⊂': '&sub;',
  '⫅': '&subE;',
  '⪽': '&subdot;',
  '⫃': '&subedot;',
  '⫁': '&submult;',
  '⫋': '&subnE;',
  '⊊': '&subne;',
  '⪿': '&subplus;',
  '⥹': '&subrarr;',
  '⫇': '&subsim;',
  '⫕': '&subsub;',
  '⫓': '&subsup;',
  '♪': '&sung;',
  '¹': '&sup1;',
  '²': '&sup2;',
  '³': '&sup3;',
  '⫆': '&supE;',
  '⪾': '&supdot;',
  '⫘': '&supdsub;',
  '⫄': '&supedot;',
  '⟉': '&suphsol;',
  '⫗': '&suphsub;',
  '⥻': '&suplarr;',
  '⫂': '&supmult;',
  '⫌': '&supnE;',
  '⊋': '&supne;',
  '⫀': '&supplus;',
  '⫈': '&supsim;',
  '⫔': '&supsub;',
  '⫖': '&supsup;',
  '⇙': '&swArr;',
  '⤪': '&swnwar;',
  'ß': '&szlig;',
  '⌖': '&target;',
  'τ': '&tau;',
  'ť': '&tcaron;',
  'ţ': '&tcedil;',
  'т': '&tcy;',
  '⌕': '&telrec;',
  '𝔱': '&tfr;',
  'θ': '&theta;',
  'ϑ': '&thetasym;',
  'þ': '&thorn;',
  '×': '&times;',
  '⨱': '&timesbar;',
  '⨰': '&timesd;',
  '⌶': '&topbot;',
  '⫱': '&topcir;',
  '𝕥': '&topf;',
  '⫚': '&topfork;',
  '‴': '&tprime;',
  '▵': '&triangle;',
  '▿': '&triangledown;',
  '≜': '&triangleq;',
  '◬': '&tridot;',
  '⨺': '&triminus;',
  '⨹': '&triplus;',
  '⧍': '&trisb;',
  '⨻': '&tritime;',
  '⏢': '&trpezium;',
  '𝓉': '&tscr;',
  'ц': '&tscy;',
  'ћ': '&tshcy;',
  'ŧ': '&tstrok;',
  '⥣': '&uHar;',
  'ú': '&uacute;',
  'ў': '&ubrcy;',
  'ŭ': '&ubreve;',
  'û': '&ucirc;',
  'у': '&ucy;',
  'ű': '&udblac;',
  '⥾': '&ufisht;',
  '𝔲': '&ufr;',
  'ù': '&ugrave;',
  '▀': '&uhblk;',
  '⌜': '&ulcorn;',
  '⌏': '&ulcrop;',
  '◸': '&ultri;',
  'ū': '&umacr;',
  'ų': '&uogon;',
  '𝕦': '&uopf;',
  'υ': '&upsi;',
  '⇈': '&upuparrows;',
  '⌝': '&urcorn;',
  '⌎': '&urcrop;',
  'ů': '&uring;',
  '◹': '&urtri;',
  '𝓊': '&uscr;',
  '⋰': '&utdot;',
  'ũ': '&utilde;',
  'ü': '&uuml;',
  '⦧': '&uwangle;',
  '⫨': '&vBar;',
  '⫩': '&vBarv;',
  '⦜': '&vangrt;',
  '∅': '&varnothing;',
  '⊊︀': '&varsubsetneq;',
  '⫋︀': '&varsubsetneqq;',
  '⊋︀': '&varsupsetneq;',
  '⫌︀': '&varsupsetneqq;',
  'в': '&vcy;',
  '⊻': '&veebar;',
  '≚': '&veeeq;',
  '⋮': '&vellip;',
  '𝔳': '&vfr;',
  '𝕧': '&vopf;',
  '𝓋': '&vscr;',
  '⦚': '&vzigzag;',
  'ŵ': '&wcirc;',
  '⩟': '&wedbar;',
  '≙': '&wedgeq;',
  '℘': '&weierp;',
  '𝔴': '&wfr;',
  '𝕨': '&wopf;',
  '𝓌': '&wscr;',
  '𝔵': '&xfr;',
  'ξ': '&xi;',
  '⋻': '&xnis;',
  '𝕩': '&xopf;',
  '𝓍': '&xscr;',
  'ý': '&yacute;',
  'я': '&yacy;',
  'ŷ': '&ycirc;',
  'ы': '&ycy;',
  '¥': '&yen;',
  '𝔶': '&yfr;',
  'ї': '&yicy;',
  '𝕪': '&yopf;',
  '𝓎': '&yscr;',
  'ю': '&yucy;',
  'ÿ': '&yuml;',
  'ź': '&zacute;',
  'ž': '&zcaron;',
  'з': '&zcy;',
  'ż': '&zdot;',
  'ζ': '&zeta;',
  '𝔷': '&zfr;',
  'ж': '&zhcy;',
  '⇝': '&zigrarr;',
  '𝕫': '&zopf;',
  '𝓏': '&zscr;',
  '‍': '&zwj;',
  '‌': '&zwnj;'
};